@@ -3,11 +3,10 @@ import { FormEvent, HTMLProps, useEffect, useRef } from 'react';
 import * as React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { useStyles2, getInputStyles, sharedInputStyle, Tooltip, Icon, Spinner } from '@grafana/ui';
-import { getFocusStyles } from '@grafana/ui/src/themes/mixins';
-import { Trans } from 'app/core/internationalization';
-
-import { Role } from '../../../types';
+import { getFocusStyles } from '@grafana/ui/internal';
+import { Role } from 'app/types/accessControl';
 
 import { ValueContainer } from './ValueContainer';
 import { ROLE_PICKER_WIDTH } from './constants';
@@ -89,7 +88,7 @@ export const RolePickerInput = ({
           onMouseDown={stopPropagation}
           onChange={onInputChange}
           data-testid="role-picker-input"
-          placeholder={isFocused ? 'Select role' : ''}
+          placeholder={isFocused ? t('role-picker.input.placeholder-select-role', 'Select role') : undefined}
           value={query}
         />
       )}
