@@ -1,5 +1,12 @@
-import { DataSourceApi, dateTime, ExploreUrlState, GrafanaConfig, locationUtil, LogsSortOrder } from '@grafana/data';
-import { serializeStateToUrlParam } from '@grafana/data/src/utils/url';
+import {
+  DataSourceApi,
+  dateTime,
+  ExploreUrlState,
+  GrafanaConfig,
+  locationUtil,
+  LogsSortOrder,
+  serializeStateToUrlParam,
+} from '@grafana/data';
 import { config } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
 import { RefreshPicker } from '@grafana/ui';
@@ -243,27 +250,35 @@ describe('when buildQueryTransaction', () => {
   it('it should calculate interval based on time range', () => {
     const queries = [{ refId: 'A' }];
     const queryOptions = { maxDataPoints: 1000, minInterval: '15s' };
-    const range = { from: dateTime().subtract(1, 'd'), to: dateTime(), raw: { from: '1h', to: '1h' } };
+    const from = dateTime('2023-01-01T12:00:00Z');
+    const to = dateTime('2023-01-02T12:00:00Z');
+    const range = { from, to, raw: { from: '1h', to: '1h' } };
     const transaction = buildQueryTransaction('left', queries, queryOptions, range, false);
     expect(transaction.request.intervalMs).toEqual(60000);
   });
   it('it should calculate interval taking minInterval into account', () => {
     const queries = [{ refId: 'A' }];
     const queryOptions = { maxDataPoints: 1000, minInterval: '15s' };
-    const range = { from: dateTime().subtract(1, 'm'), to: dateTime(), raw: { from: '1h', to: '1h' } };
+    const from = dateTime('2023-01-01T12:00:00Z');
+    const to = dateTime('2023-01-01T12:01:00Z');
+    const range = { from, to, raw: { from: '1h', to: '1h' } };
     const transaction = buildQueryTransaction('left', queries, queryOptions, range, false);
     expect(transaction.request.intervalMs).toEqual(15000);
   });
   it('it should calculate interval taking maxDataPoints into account', () => {
     const queries = [{ refId: 'A' }];
     const queryOptions = { maxDataPoints: 10, minInterval: '15s' };
-    const range = { from: dateTime().subtract(1, 'd'), to: dateTime(), raw: { from: '1h', to: '1h' } };
+    const from = dateTime('2023-01-01T12:00:00Z');
+    const to = dateTime('2023-01-02T12:00:00Z');
+    const range = { from, to, raw: { from: '1h', to: '1h' } };
     const transaction = buildQueryTransaction('left', queries, queryOptions, range, false);
     expect(transaction.request.interval).toEqual('2h');
   });
   it('it should create a request with X-Cache-Skip set to true', () => {
     const queries = [{ refId: 'A' }];
-    const range = { from: dateTime().subtract(1, 'd'), to: dateTime(), raw: { from: '1h', to: '1h' } };
+    const from = dateTime('2023-01-01T12:00:00Z');
+    const to = dateTime('2023-01-02T12:00:00Z');
+    const range = { from, to, raw: { from: '1h', to: '1h' } };
     const transaction = buildQueryTransaction('left', queries, {}, range, false);
     expect(transaction.request.skipQueryCache).toBe(true);
   });
