@@ -3,6 +3,7 @@ import { Dispatch, SetStateAction, useEffect, useId, useState } from 'react';
 import { Controller, useFormContext } from 'react-hook-form';
 
 import { GrafanaTheme2, SelectableValue } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import {
   useStyles2,
   Button,
@@ -22,8 +23,7 @@ import {
   RadioButtonGroup,
   SecretInput,
 } from '@grafana/ui';
-import { t, Trans } from 'app/core/internationalization';
-import { LdapPayload, MapKeyCertConfigured } from 'app/types';
+import { MapKeyCertConfigured, LdapPayload } from 'app/types/ldap';
 
 import { GroupMappingComponent } from './LdapGroupMapping';
 
@@ -98,7 +98,7 @@ export const LdapDrawerComponent = ({
       <Trans i18nKey="ldap-drawer.extra-security-section.use-ssl-tooltip">
         For a complete list of supported ciphers and TLS versions, refer to:
       </Trans>{' '}
-      {/* eslint-disable-next-line @grafana/no-untranslated-strings */}
+      {/* eslint-disable-next-line @grafana/i18n/no-untranslated-strings */}
       <TextLink style={{ fontSize: 'inherit' }} href="https://go.dev/src/crypto/tls/cipher_suites.go" external>
         https://go.dev/src/crypto/tls/cipher_suites.go
       </TextLink>
@@ -144,6 +144,7 @@ export const LdapDrawerComponent = ({
         >
           <Input
             id="port"
+            // eslint-disable-next-line @grafana/i18n/no-untranslated-strings
             placeholder="389"
             type="number"
             {...register(`${serverConfig}.port`, { valueAsNumber: true })}
@@ -158,6 +159,7 @@ export const LdapDrawerComponent = ({
         >
           <Input
             id="timeout"
+            // eslint-disable-next-line @grafana/i18n/no-untranslated-strings
             placeholder="10"
             type="number"
             {...register(`${serverConfig}.timeout`, { valueAsNumber: true })}
@@ -411,10 +413,8 @@ export const LdapDrawerComponent = ({
                 <Field label={t('ldap-drawer.extra-security-section.client-cert-label', 'Client certificate path')}>
                   <Input
                     id="client-cert"
-                    placeholder={t(
-                      'ldap-drawer.extra-security-section.client-cert-placeholder',
-                      '/path/to/client_cert.pem'
-                    )}
+                    // eslint-disable-next-line @grafana/i18n/no-untranslated-strings
+                    placeholder="/path/to/client_cert.pem"
                     type="text"
                     {...register(`${serverConfig}.client_cert`)}
                   />
