@@ -2,7 +2,7 @@ import { isEmpty } from 'lodash';
 
 import { encodeMatcher } from 'app/features/alerting/unified/utils/matchers';
 import { dispatch } from 'app/store/store';
-import { ReceiversStateDTO } from 'app/types/alerting';
+import { NotificationChannelOption, NotifierDTO, ReceiversStateDTO } from 'app/types/alerting';
 
 import {
   AlertManagerCortexConfig,
@@ -12,11 +12,8 @@ import {
   ExternalAlertmanagersConnectionStatus,
   ExternalAlertmanagersStatusResponse,
   GrafanaAlertingConfiguration,
-  GrafanaManagedContactPoint,
   Matcher,
-  MuteTimeInterval,
 } from '../../../../plugins/datasource/alertmanager/types';
-import { NotifierDTO } from '../../../../types';
 import { withPerformanceLogging } from '../Analytics';
 import { matcherToMatcherField } from '../utils/alertmanager';
 import {
@@ -108,6 +105,25 @@ export const alertmanagerApi = alertingApi.injectEndpoints({
 
     grafanaNotifiers: build.query<NotifierDTO[], void>({
       query: () => ({ url: '/api/alert-notifiers' }),
+      transformResponse: (response: NotifierDTO[]) => {
+        const populateSecureFieldKey = (
+          option: NotificationChannelOption,
+          prefix: string
+        ): NotificationChannelOption => ({
+          ...option,
+          secureFieldKey: option.secure && !option.secureFieldKey ? `${prefix}${option.propertyName}` : undefined,
+          subformOptions: option.subformOptions?.map((suboption) =>
+            populateSecureFieldKey(suboption, `${prefix}${option.propertyName}.`)
+          ),
+        });
+
+        return response.map((notifier) => ({
+          ...notifier,
+          options: notifier.options.map((option) => {
+            return populateSecureFieldKey(option, '');
+          }),
+        }));
+      },
     }),
 
     // this endpoint requires administrator privileges
@@ -197,8 +213,8 @@ export const alertmanagerApi = alertingApi.injectEndpoints({
 
         // wrap our fetchConfig function with some performance logging functions
         const fetchAMconfigWithLogging = withPerformanceLogging(
-          'unifiedalerting/fetchAmConfig',
           fetchAlertManagerConfig,
+          'unifiedalerting/fetchAmConfig',
           {
             dataSourceName: alertmanagerSourceName,
             thunk: 'unifiedalerting/fetchAmConfig',
@@ -293,15 +309,5 @@ export const alertmanagerApi = alertingApi.injectEndpoints({
       },
       providesTags: ['ContactPointsStatus'],
     }),
-    // Grafana Managed Alertmanager only
-    // TODO: Remove as part of migration to k8s API for receivers
-    getContactPointsList: build.query<GrafanaManagedContactPoint[], void>({
-      query: () => ({ url: '/api/v1/notifications/receivers' }),
-      providesTags: ['ContactPoint'],
-    }),
-    getMuteTimingList: build.query<MuteTimeInterval[], void>({
-      query: () => ({ url: '/api/v1/notifications/time-intervals' }),
-      providesTags: ['AlertmanagerConfiguration'],
-    }),
   }),
 });
