@@ -3,14 +3,11 @@ import { ComponentProps, ReactNode } from 'react';
 import { render, screen, userEvent, waitFor, waitForElementToBeRemoved, within } from 'test/test-utils';
 
 import { selectors } from '@grafana/e2e-selectors';
-import {
-  flushMicrotasks,
-  testWithFeatureToggles,
-  testWithLicenseFeatures,
-} from 'app/features/alerting/unified/test/test-utils';
+import { MIMIR_DATASOURCE_UID } from 'app/features/alerting/unified/mocks/server/constants';
+import { flushMicrotasks } from 'app/features/alerting/unified/test/test-utils';
 import { K8sAnnotations } from 'app/features/alerting/unified/utils/k8s/constants';
 import { AlertManagerDataSourceJsonData, AlertManagerImplementation } from 'app/plugins/datasource/alertmanager/types';
-import { AccessControlAction } from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
 
 import { setupMswServer } from '../../mockApi';
 import { grantUserPermissions, mockDataSource } from '../../mocks';
@@ -19,12 +16,12 @@ import { setupDataSources } from '../../testSetup/datasources';
 import { DataSourceType, GRAFANA_RULES_SOURCE_NAME } from '../../utils/datasource';
 
 import { ContactPoint } from './ContactPoint';
-import ContactPointsPageContents from './ContactPoints';
-import setupMimirFlavoredServer, { MIMIR_DATASOURCE_UID } from './__mocks__/mimirFlavoredServer';
+import { ContactPointsPageContents } from './ContactPoints';
+import { RECEIVER_META_KEY } from './constants';
+import setupMimirFlavoredServer from './mocks/mimirFlavoredServer';
 import setupVanillaAlertmanagerFlavoredServer, {
   VANILLA_ALERTMANAGER_DATASOURCE_UID,
-} from './__mocks__/vanillaAlertmanagerServer';
-import { RECEIVER_META_KEY } from './constants';
+} from './mocks/vanillaAlertmanagerServer';
 import { ContactPointWithMetadata, ReceiverConfigWithMetadata, RouteReference } from './utils';
 
 /**
@@ -63,6 +60,16 @@ const basicContactPoint: ContactPointWithMetadata = {
   grafana_managed_receiver_configs: [],
 };
 
+const basicContactPointInUse: ContactPointWithMetadata = {
+  ...basicContactPoint,
+  metadata: {
+    annotations: {
+      [K8sAnnotations.InUseRules]: '1',
+      [K8sAnnotations.InUseRoutes]: '1',
+    },
+  },
+};
+
 const contactPointWithEverything: ContactPointWithMetadata = {
   ...basicContactPoint,
   metadata: {
@@ -95,7 +102,26 @@ const attemptDeleteContactPoint = async (name: string) => {
   return user.click(await screen.findByRole('button', { name: /delete contact point/i }));
 };
 
+const alertManager = mockDataSource<AlertManagerDataSourceJsonData>({
+  name: VANILLA_ALERTMANAGER_DATASOURCE_UID,
+  uid: VANILLA_ALERTMANAGER_DATASOURCE_UID,
+  type: DataSourceType.Alertmanager,
+  jsonData: {
+    implementation: AlertManagerImplementation.prometheus,
+    handleGrafanaManagedAlerts: true,
+  },
+});
+
+const mimirDatasource = mockDataSource({
+  type: DataSourceType.Alertmanager,
+  name: MIMIR_DATASOURCE_UID,
+  uid: MIMIR_DATASOURCE_UID,
+});
+
 describe('contact points', () => {
+  beforeEach(() => {
+    setupDataSources(alertManager, mimirDatasource);
+  });
   describe('Contact points with Grafana managed alertmanager', () => {
     beforeEach(() => {
       grantUserPermissions([
@@ -128,6 +154,32 @@ describe('contact points', () => {
 
         expect(await screen.findByText(/create contact point/i)).toBeInTheDocument();
       });
+
+      test('defaults to contact points tab if user has only read permission', async () => {
+        grantUserPermissions([AccessControlAction.AlertingReceiversRead]);
+        renderWithProvider(<ContactPointsPageContents />);
+
+        expect(await screen.findByText(/create contact point/i)).toBeInTheDocument();
+      });
+
+      test('defaults to contact points tab if user has only create permission', async () => {
+        grantUserPermissions([AccessControlAction.AlertingReceiversCreate]);
+        renderWithProvider(<ContactPointsPageContents />);
+
+        expect(await screen.findByText(/create contact point/i)).toBeInTheDocument();
+      });
+    });
+
+    describe('templates tab', () => {
+      it('does not show a warning for a "misconfigured" template', async () => {
+        renderWithProvider(
+          <ContactPointsPageContents />,
+          { initialEntries: ['/?tab=templates'] },
+          { alertmanagerSourceName: GRAFANA_RULES_SOURCE_NAME }
+        );
+        await screen.findByText(/create notification templates/i);
+        expect(screen.queryByText(/^misconfigured$/i)).not.toBeInTheDocument();
+      });
     });
 
     it('should show / hide loading states, have all actions enabled', async () => {
@@ -143,15 +195,14 @@ describe('contact points', () => {
       expect(screen.getByRole('link', { name: 'add contact point' })).toBeInTheDocument();
       expect(screen.getByRole('button', { name: 'export all' })).toBeInTheDocument();
 
-      // 2 of them are unused by routes in the mock response
       const unusedBadge = screen.getAllByLabelText('unused');
-      expect(unusedBadge).toHaveLength(3);
+      expect(unusedBadge).toHaveLength(4);
 
-      const viewProvisioned = screen.getByRole('link', { name: 'view-action' });
+      const viewProvisioned = screen.getByTestId('view-action');
       expect(viewProvisioned).toBeInTheDocument();
       expect(viewProvisioned).toBeEnabled();
 
-      const editButtons = screen.getAllByRole('link', { name: 'edit-action' });
+      const editButtons = screen.getAllByTestId('edit-action');
       expect(editButtons).toHaveLength(4);
       editButtons.forEach((button) => {
         expect(button).toBeEnabled();
@@ -175,30 +226,21 @@ describe('contact points', () => {
       // should disable create contact point
       expect(screen.getByRole('link', { name: 'add contact point' })).toHaveAttribute('aria-disabled', 'true');
 
-      // there should be no edit buttons
-      expect(screen.queryAllByRole('link', { name: 'edit-action' })).toHaveLength(0);
+      // edit permission is based on API response - we should have 3 buttons
+      const editButtons = await screen.findAllByTestId('edit-action');
+      expect(editButtons).toHaveLength(3);
 
-      // there should be view buttons though
-      const viewButtons = screen.getAllByRole('link', { name: 'view-action' });
-      expect(viewButtons).toHaveLength(5);
-
-      // delete should be disabled in the "more" actions
-      const moreButtons = screen.queryAllByRole('button', { name: /More/ });
-      expect(moreButtons).toHaveLength(5);
-
-      // check if all of the delete buttons are disabled
-      for await (const button of moreButtons) {
-        await user.click(button);
-        const deleteButton = screen.queryByRole('menuitem', { name: 'delete' });
-        expect(deleteButton).toBeDisabled();
-        // click outside the menu to close it otherwise we can't interact with the rest of the page
-        await user.click(document.body);
-      }
+      // there should be view buttons though - one for provisioned, and one for the un-editable contact point
+      const viewButtons = screen.getAllByTestId('view-action');
+      expect(viewButtons).toHaveLength(2);
 
       // check buttons in Notification Templates
       const notificationTemplatesTab = screen.getByRole('tab', { name: 'Notification Templates' });
       await user.click(notificationTemplatesTab);
-      expect(screen.getByRole('link', { name: 'Add notification template' })).toHaveAttribute('aria-disabled', 'true');
+      expect(screen.getByRole('link', { name: 'Add notification template group' })).toHaveAttribute(
+        'aria-disabled',
+        'true'
+      );
     });
 
     it('allows deleting when not disabled', async () => {
@@ -266,7 +308,7 @@ describe('contact points', () => {
         },
       ];
 
-      const { user } = renderWithProvider(<ContactPoint contactPoint={{ ...basicContactPoint, policies }} />);
+      const { user } = renderWithProvider(<ContactPoint contactPoint={{ ...basicContactPointInUse, policies }} />);
 
       expect(screen.getByRole('link', { name: /1 notification policy/ })).toBeInTheDocument();
 
@@ -325,13 +367,6 @@ describe('contact points', () => {
         AccessControlAction.AlertingNotificationsExternalRead,
         AccessControlAction.AlertingNotificationsExternalWrite,
       ]);
-      setupDataSources(
-        mockDataSource({
-          type: DataSourceType.Alertmanager,
-          name: MIMIR_DATASOURCE_UID,
-          uid: MIMIR_DATASOURCE_UID,
-        })
-      );
     });
 
     it('should show / hide loading states, have the right actions enabled', async () => {
@@ -352,7 +387,7 @@ describe('contact points', () => {
       const unusedBadge = screen.getAllByLabelText('unused');
       expect(unusedBadge).toHaveLength(1);
 
-      const editButtons = screen.getAllByRole('link', { name: 'edit-action' });
+      const editButtons = screen.getAllByTestId('edit-action');
       expect(editButtons).toHaveLength(2);
       editButtons.forEach((button) => {
         expect(button).toBeEnabled();
@@ -364,6 +399,17 @@ describe('contact points', () => {
         expect(button).toBeEnabled();
       });
     });
+
+    describe('templates tab', () => {
+      it('shows a warning when a template is misconfigured', async () => {
+        renderWithProvider(
+          <ContactPointsPageContents />,
+          { initialEntries: ['/?tab=templates'] },
+          { alertmanagerSourceName: MIMIR_DATASOURCE_UID }
+        );
+        expect((await screen.findAllByText(/^misconfigured$/i))[0]).toBeInTheDocument();
+      });
+    });
   });
 
   describe('Vanilla Alertmanager ', () => {
@@ -373,23 +419,11 @@ describe('contact points', () => {
         AccessControlAction.AlertingNotificationsExternalRead,
         AccessControlAction.AlertingNotificationsExternalWrite,
       ]);
-
-      const alertManager = mockDataSource<AlertManagerDataSourceJsonData>({
-        name: VANILLA_ALERTMANAGER_DATASOURCE_UID,
-        uid: VANILLA_ALERTMANAGER_DATASOURCE_UID,
-        type: DataSourceType.Alertmanager,
-        jsonData: {
-          implementation: AlertManagerImplementation.prometheus,
-          handleGrafanaManagedAlerts: true,
-        },
-      });
-
-      setupDataSources(alertManager);
     });
 
     it("should not allow any editing because it's not supported", async () => {
       const { user } = renderWithProvider(<ContactPointsPageContents />, undefined, {
-        alertmanagerSourceName: VANILLA_ALERTMANAGER_DATASOURCE_UID,
+        alertmanagerSourceName: alertManager.name,
       });
 
       await waitForElementToBeRemoved(screen.queryByText('Loading...'));
@@ -397,20 +431,18 @@ describe('contact points', () => {
 
       expect(screen.queryByRole('link', { name: 'add contact point' })).not.toBeInTheDocument();
 
-      const viewProvisioned = screen.getByRole('link', { name: 'view-action' });
+      const viewProvisioned = screen.getByTestId('view-action');
       expect(viewProvisioned).toBeInTheDocument();
       expect(viewProvisioned).toBeEnabled();
 
       // check buttons in Notification Templates
       const notificationTemplatesTab = screen.getByRole('tab', { name: 'Notification Templates' });
       await user.click(notificationTemplatesTab);
-      expect(screen.queryByRole('link', { name: 'Add notification template' })).not.toBeInTheDocument();
+      expect(screen.queryByRole('link', { name: 'Add notification template group' })).not.toBeInTheDocument();
     });
   });
 
-  describe('alertingApiServer enabled', () => {
-    testWithFeatureToggles(['alertingApiServer']);
-
+  describe('Grafana alertmanager', () => {
     beforeEach(() => {
       grantUserPermissions([
         AccessControlAction.AlertingNotificationsRead,
@@ -533,32 +565,20 @@ describe('contact points', () => {
       ).toBeInTheDocument();
     });
 
-    it('does not show manage permissions', async () => {
-      renderGrafanaContactPoints();
+    it('shows manage permissions and allows closing', async () => {
+      const { user } = renderGrafanaContactPoints();
 
       await clickMoreActionsButton('lotsa-emails');
 
-      expect(screen.queryByRole('menuitem', { name: /manage permissions/i })).not.toBeInTheDocument();
-    });
+      await user.click(await screen.findByRole('menuitem', { name: /manage permissions/i }));
 
-    describe('accesscontrol license feature enabled', () => {
-      testWithLicenseFeatures(['accesscontrol']);
+      const permissionsDialog = await screen.findByRole('dialog', { name: /drawer title manage permissions/i });
 
-      it('shows manage permissions and allows closing', async () => {
-        const { user } = renderGrafanaContactPoints();
+      expect(permissionsDialog).toBeInTheDocument();
+      expect(await screen.findByRole('table')).toBeInTheDocument();
 
-        await clickMoreActionsButton('lotsa-emails');
-
-        await user.click(await screen.findByRole('menuitem', { name: /manage permissions/i }));
-
-        const permissionsDialog = await screen.findByRole('dialog', { name: /drawer title manage permissions/i });
-
-        expect(permissionsDialog).toBeInTheDocument();
-        expect(await screen.findByRole('table')).toBeInTheDocument();
-
-        await user.click(within(permissionsDialog).getAllByRole('button', { name: /close/i })[0]);
-        expect(permissionsDialog).not.toBeInTheDocument();
-      });
+      await user.click(within(permissionsDialog).getAllByRole('button', { name: /close/i })[0]);
+      expect(permissionsDialog).not.toBeInTheDocument();
     });
   });
 });
