@@ -1,5 +1,6 @@
 import { Navigate } from 'react-router-dom-v5-compat';
 
+import { t } from '@grafana/i18n';
 import { useGetMuteTiming } from 'app/features/alerting/unified/components/mute-timings/useMuteTimings';
 import { useURLSearchParams } from 'app/features/alerting/unified/hooks/useURLSearchParams';
 
@@ -42,7 +43,10 @@ function EditMuteTimingPage() {
   return (
     <AlertmanagerPageWrapper
       navId="am-routes"
-      pageNav={{ id: 'alert-policy-edit', text: 'Edit mute timing' }}
+      pageNav={{
+        id: 'alert-policy-edit',
+        text: t('alerting.edit-mute-timing-page.text.edit-time-interval', 'Edit time interval'),
+      }}
       accessType="notification"
     >
       <EditTimingRoute />
