@@ -1,36 +1,57 @@
 import { css } from '@emotion/css';
-import { chain, isEmpty, truncate } from 'lodash';
-import { useState } from 'react';
+import { chain, truncate } from 'lodash';
+import { useEffect, useState } from 'react';
 import { useMeasure } from 'react-use';
 
 import { NavModelItem, UrlQueryValue } from '@grafana/data';
-import { Alert, LinkButton, LoadingBar, Stack, TabContent, Text, TextLink, useStyles2 } from '@grafana/ui';
-import { t, Trans } from '@grafana/ui/src/utils/i18n';
+import { Trans, t } from '@grafana/i18n';
+import {
+  Alert,
+  LinkButton,
+  LoadingBar,
+  Stack,
+  TabContent,
+  Text,
+  TextLink,
+  useStyles2,
+  withErrorBoundary,
+} from '@grafana/ui';
 import { PageInfoItem } from 'app/core/components/Page/types';
 import { useQueryParams } from 'app/core/hooks/useQueryParams';
 import InfoPausedRule from 'app/features/alerting/unified/components/InfoPausedRule';
 import { RuleActionsButtons } from 'app/features/alerting/unified/components/rules/RuleActionsButtons';
-import { AlertInstanceTotalState, CombinedRule, RuleHealth, RuleIdentifier } from 'app/types/unified-alerting';
+import {
+  AlertInstanceTotalState,
+  AlertInstanceTotals,
+  CombinedRule,
+  RuleGroupIdentifierV2,
+  RuleHealth,
+  RuleIdentifier,
+} from 'app/types/unified-alerting';
 import { PromAlertingRuleState, PromRuleType } from 'app/types/unified-alerting-dto';
 
+import { logError } from '../../Analytics';
 import { defaultPageNav } from '../../RuleViewer';
-import { shouldUsePrometheusRulesPrimary } from '../../featureToggles';
-import { usePrometheusCreationConsistencyCheck } from '../../hooks/usePrometheusConsistencyCheck';
+import { shouldUseAlertingListViewV2, shouldUsePrometheusRulesPrimary } from '../../featureToggles';
+import { isError, useAsync } from '../../hooks/useAsync';
+import { useRuleLocation } from '../../hooks/useCombinedRule';
+import { useHasRulerV2 } from '../../hooks/useHasRuler';
+import { useRuleGroupConsistencyCheck } from '../../hooks/usePrometheusConsistencyCheck';
 import { useReturnTo } from '../../hooks/useReturnTo';
 import { PluginOriginBadge } from '../../plugins/PluginOriginBadge';
 import { Annotation } from '../../utils/constants';
+import { ruleIdentifierToRuleSourceIdentifier } from '../../utils/datasource';
+import { labelsSize } from '../../utils/labels';
 import { makeDashboardLink, makePanelLink, stringifyErrorLike } from '../../utils/misc';
+import { createListFilterLink } from '../../utils/navigation';
 import {
-  getRulePluginOrigin,
-  isAlertingRule,
-  isFederatedRuleGroup,
-  isGrafanaRecordingRule,
-  isGrafanaRulerRule,
-  isGrafanaRulerRulePaused,
-  isRecordingRule,
   RulePluginOrigin,
+  getRulePluginOrigin,
+  isFederatedRuleGroup,
+  isPausedRule,
+  prometheusRuleType,
+  rulerRuleType,
 } from '../../utils/rules';
-import { createRelativeUrl } from '../../utils/url';
 import { AlertLabels } from '../AlertLabels';
 import { AlertingPageWrapper } from '../AlertingPageWrapper';
 import { ProvisionedResource, ProvisioningAlert } from '../Provisioning';
@@ -38,10 +59,12 @@ import { WithReturnButton } from '../WithReturnButton';
 import { decodeGrafanaNamespace } from '../expressions/util';
 import { RedirectToCloneRule } from '../rules/CloneRule';
 
+import { ContactPointLink } from './ContactPointLink';
 import { FederatedRuleWarning } from './FederatedRuleWarning';
 import PausedBadge from './PausedBadge';
 import { useAlertRule } from './RuleContext';
 import { RecordingBadge, StateBadge } from './StateBadges';
+import { AlertVersionHistory } from './tabs/AlertVersionHistory';
 import { Details } from './tabs/Details';
 import { History } from './tabs/History';
 import { InstancesList } from './tabs/Instances';
@@ -54,9 +77,13 @@ export enum ActiveTab {
   History = 'history',
   Routing = 'routing',
   Details = 'details',
+  VersionHistory = 'version-history',
 }
 
 const prometheusRulesPrimary = shouldUsePrometheusRulesPrimary();
+const alertingListViewV2 = shouldUseAlertingListViewV2();
+
+const shouldUseConsistencyCheck = prometheusRulesPrimary || alertingListViewV2;
 
 const RuleViewer = () => {
   const { rule, identifier } = useAlertRule();
@@ -66,18 +93,17 @@ const RuleViewer = () => {
   // we want to be able to show a modal if the rule has been provisioned explain the limitations
   // of duplicating provisioned alert rules
   const [duplicateRuleIdentifier, setDuplicateRuleIdentifier] = useState<RuleIdentifier>();
+  const { returnTo } = useReturnTo('/alerting/list');
+  const { annotations, promRule, rulerRule } = rule;
 
-  const { annotations, promRule } = rule;
-  const hasError = isErrorHealth(rule.promRule?.health);
-
-  const isAlertType = isAlertingRule(promRule);
+  const hasError = isErrorHealth(promRule?.health);
 
   const isFederatedRule = isFederatedRuleGroup(rule.group);
-  const isProvisioned = isGrafanaRulerRule(rule.rulerRule) && Boolean(rule.rulerRule.grafana_alert.provenance);
-  const isPaused = isGrafanaRulerRule(rule.rulerRule) && isGrafanaRulerRulePaused(rule.rulerRule);
+  const isProvisioned = rulerRuleType.grafana.rule(rulerRule) && Boolean(rulerRule.grafana_alert.provenance);
+  const isPaused = rulerRuleType.grafana.rule(rulerRule) && isPausedRule(rulerRule);
 
   const showError = hasError && !isPaused;
-  const ruleOrigin = getRulePluginOrigin(rule);
+  const ruleOrigin = rulerRule ? getRulePluginOrigin(rulerRule) : getRulePluginOrigin(promRule);
 
   const summary = annotations[Annotation.summary];
 
@@ -90,19 +116,20 @@ const RuleViewer = () => {
         <Title
           name={title}
           paused={isPaused}
-          state={isAlertType ? promRule.state : undefined}
-          health={rule.promRule?.health}
-          ruleType={rule.promRule?.type}
+          state={prometheusRuleType.alertingRule(promRule) ? promRule.state : undefined}
+          health={promRule?.health}
+          ruleType={promRule?.type}
           ruleOrigin={ruleOrigin}
+          returnToHref={returnTo}
         />
       )}
-      actions={<RuleActionsButtons rule={rule} showCopyLinkButton rulesSource={rule.namespace.rulesSource} />}
+      actions={<RuleActionsButtons rule={rule} rulesSource={rule.namespace.rulesSource} />}
       info={createMetadata(rule)}
       subTitle={
         <Stack direction="column">
-          {isPaused && <InfoPausedRule />}
           {summary}
           {/* alerts and notifications and stuff */}
+          {isPaused && <InfoPausedRule />}
           {isFederatedRule && <FederatedRuleWarning />}
           {/* indicator for rules in a provisioned group */}
           {isProvisioned && (
@@ -110,7 +137,14 @@ const RuleViewer = () => {
           )}
           {/* error state */}
           {showError && (
-            <Alert title="Something went wrong when evaluating this alert rule" bottomSpacing={0} topSpacing={2}>
+            <Alert
+              title={t(
+                'alerting.rule-viewer.title-something-wrong-evaluating-alert',
+                'Something went wrong when evaluating this alert rule'
+              )}
+              bottomSpacing={0}
+              topSpacing={2}
+            >
               <pre style={{ marginBottom: 0 }}>
                 <code>{rule.promRule?.lastError ?? 'No error message'}</code>
               </pre>
@@ -119,15 +153,20 @@ const RuleViewer = () => {
         </Stack>
       }
     >
-      {prometheusRulesPrimary && <PrometheusConsistencyCheck ruleIdentifier={identifier} />}
+      {shouldUseConsistencyCheck && <PrometheusConsistencyCheck ruleIdentifier={identifier} />}
       <Stack direction="column" gap={2}>
         {/* tabs and tab content */}
         <TabContent>
           {activeTab === ActiveTab.Query && <QueryResults rule={rule} />}
           {activeTab === ActiveTab.Instances && <InstancesList rule={rule} />}
-          {activeTab === ActiveTab.History && isGrafanaRulerRule(rule.rulerRule) && <History rule={rule.rulerRule} />}
+          {activeTab === ActiveTab.History && rulerRuleType.grafana.rule(rule.rulerRule) && (
+            <History rule={rule.rulerRule} />
+          )}
           {activeTab === ActiveTab.Routing && <Routing />}
           {activeTab === ActiveTab.Details && <Details rule={rule} />}
+          {activeTab === ActiveTab.VersionHistory && rulerRuleType.grafana.rule(rule.rulerRule) && (
+            <AlertVersionHistory rule={rule.rulerRule} />
+          )}
         </TabContent>
       </Stack>
       {duplicateRuleIdentifier && (
@@ -143,7 +182,7 @@ const RuleViewer = () => {
 };
 
 const createMetadata = (rule: CombinedRule): PageInfoItem[] => {
-  const { labels, annotations, group } = rule;
+  const { labels, annotations, group, rulerRule } = rule;
   const metadata: PageInfoItem[] = [];
 
   const runbookUrl = annotations[Annotation.runbookURL];
@@ -152,35 +191,48 @@ const createMetadata = (rule: CombinedRule): PageInfoItem[] => {
 
   const hasDashboardAndPanel = dashboardUID && panelID;
   const hasDashboard = dashboardUID;
-  const hasLabels = !isEmpty(labels);
+  const hasLabels = labelsSize(labels) > 0;
 
   const interval = group.interval;
+  const styles = useStyles2(getStyles);
+
+  // if the alert rule uses simplified routing, we'll show a link to the contact point
+  if (rulerRuleType.grafana.alertingRule(rulerRule)) {
+    const contactPointName = rulerRule.grafana_alert.notification_settings?.receiver;
+
+    if (contactPointName) {
+      metadata.push({
+        label: t('alerting.create-metadata.label.contact-point', 'Notifications are delivered to'),
+        value: <ContactPointLink name={contactPointName} variant="bodySmall" />,
+      });
+    }
+  }
 
   if (runbookUrl) {
     /* TODO instead of truncating the string, we should use flex and text overflow properly to allow it to take up all of the horizontal space available */
     const truncatedUrl = truncate(runbookUrl, { length: 42 });
     const valueToAdd = isValidRunbookURL(runbookUrl) ? (
-      <TextLink variant="bodySmall" href={runbookUrl} external>
+      <TextLink variant="bodySmall" className={styles.url} href={runbookUrl} external>
         {truncatedUrl}
       </TextLink>
     ) : (
       <Text variant="bodySmall">{truncatedUrl}</Text>
     );
     metadata.push({
-      label: 'Runbook URL',
+      label: t('alerting.create-metadata.label.runbook-url', 'Runbook URL'),
       value: valueToAdd,
     });
   }
 
   if (hasDashboardAndPanel) {
     metadata.push({
-      label: 'Dashboard and panel',
+      label: t('alerting.create-metadata.label.dashboard-and-panel', 'Dashboard and panel'),
       value: (
         <WithReturnButton
           title={rule.name}
           component={
             <TextLink variant="bodySmall" href={makePanelLink(dashboardUID, panelID)}>
-              View panel
+              <Trans i18nKey="alerting.create-metadata.view-panel">View panel</Trans>
             </TextLink>
           }
         />
@@ -188,37 +240,41 @@ const createMetadata = (rule: CombinedRule): PageInfoItem[] => {
     });
   } else if (hasDashboard) {
     metadata.push({
-      label: 'Dashboard',
+      label: t('alerting.create-metadata.label.dashboard', 'Dashboard'),
       value: (
         <WithReturnButton
           title={rule.name}
           component={
             <TextLink title={rule.name} variant="bodySmall" href={makeDashboardLink(dashboardUID)}>
-              View dashboard
+              <Trans i18nKey="alerting.create-metadata.view-dashboard">View dashboard</Trans>
             </TextLink>
           }
         />
       ),
     });
   }
-  if (isGrafanaRecordingRule(rule.rulerRule)) {
+  if (rulerRuleType.grafana.recordingRule(rule.rulerRule)) {
     const metric = rule.rulerRule?.grafana_alert.record?.metric ?? '';
     metadata.push({
-      label: 'Metric name',
+      label: t('alerting.create-metadata.label.metric-name', 'Metric name'),
       value: <Text color="primary">{metric}</Text>,
     });
   }
 
   if (interval) {
     metadata.push({
-      label: 'Evaluation interval',
-      value: <Text color="primary">Every {interval}</Text>,
+      label: t('alerting.create-metadata.label.evaluation-interval', 'Evaluation interval'),
+      value: (
+        <Text color="primary">
+          <Trans i18nKey="alerting.rule-viewer.evaluation-interval">Every {{ interval }}</Trans>
+        </Text>
+      ),
     });
   }
 
   if (hasLabels) {
     metadata.push({
-      label: 'Labels',
+      label: t('alerting.create-metadata.label.labels', 'Labels'),
       /* TODO truncate number of labels, maybe build in to component? */
       value: <AlertLabels labels={labels} size="sm" />,
     });
@@ -227,12 +283,6 @@ const createMetadata = (rule: CombinedRule): PageInfoItem[] => {
   return metadata;
 };
 
-// TODO move somewhere else
-export const createListFilterLink = (values: Array<[string, string]>) => {
-  const params = new URLSearchParams([['search', values.map(([key, value]) => `${key}:"${value}"`).join(' ')]]);
-  return createRelativeUrl(`/alerting/list`, params);
-};
-
 interface TitleProps {
   name: string;
   paused?: boolean;
@@ -241,18 +291,18 @@ interface TitleProps {
   health?: RuleHealth;
   ruleType?: PromRuleType;
   ruleOrigin?: RulePluginOrigin;
+  returnToHref?: string;
 }
 
-export const Title = ({ name, paused = false, state, health, ruleType, ruleOrigin }: TitleProps) => {
-  const styles = useStyles2(getStyles);
+export const Title = ({ name, paused = false, state, health, ruleType, ruleOrigin, returnToHref = '' }: TitleProps) => {
   const isRecordingRule = ruleType === PromRuleType.Recording;
 
-  const { returnTo } = useReturnTo('/alerting/list');
+  const { returnTo } = useReturnTo(returnToHref);
 
   return (
-    <div className={styles.title}>
-      <LinkButton variant="secondary" icon="angle-left" href={returnTo} />
-      {ruleOrigin && <PluginOriginBadge pluginId={ruleOrigin.pluginId} />}
+    <Stack direction="row" gap={1} minWidth={0} alignItems="center">
+      {returnToHref && <LinkButton variant="secondary" icon="angle-left" href={returnTo} />}
+      {ruleOrigin && <PluginOriginBadge pluginId={ruleOrigin.pluginId} size="lg" />}
       <Text variant="h1" truncate>
         {name}
       </Text>
@@ -265,45 +315,75 @@ export const Title = ({ name, paused = false, state, health, ruleType, ruleOrigi
           {isRecordingRule && <RecordingBadge health={health} />}
         </>
       )}
-    </div>
+    </Stack>
   );
 };
 
+interface PrometheusConsistencyCheckProps {
+  ruleIdentifier: RuleIdentifier;
+}
 /**
  * This component displays an Alert warning component if discovers inconsistencies between Prometheus and Ruler rules
  * It will show loading indicator until the Prometheus and Ruler rule is consistent
  * It will not show the warning if the rule is Grafana managed
  */
-function PrometheusConsistencyCheck({ ruleIdentifier }: { ruleIdentifier: RuleIdentifier }) {
-  const [ref, { width }] = useMeasure<HTMLDivElement>();
-  const { isConsistent, error } = usePrometheusCreationConsistencyCheck(ruleIdentifier);
+const PrometheusConsistencyCheck = withErrorBoundary(
+  ({ ruleIdentifier }: PrometheusConsistencyCheckProps) => {
+    const [ref, { width }] = useMeasure<HTMLDivElement>();
+
+    const { hasRuler } = useHasRulerV2(ruleIdentifierToRuleSourceIdentifier(ruleIdentifier));
+    const { result: ruleLocation } = useRuleLocation(ruleIdentifier);
+
+    const { waitForGroupConsistency, groupConsistent } = useRuleGroupConsistencyCheck();
+
+    const [waitAction, waitState] = useAsync((groupIdentifier: RuleGroupIdentifierV2) => {
+      return waitForGroupConsistency(groupIdentifier);
+    });
+
+    useEffect(() => {
+      if (ruleLocation && hasRuler) {
+        waitAction.execute(ruleLocation.groupIdentifier);
+      }
+    }, [ruleLocation, hasRuler, waitAction]);
+
+    if (isError(waitState)) {
+      return (
+        <Alert
+          title={t(
+            'alerting.prometheus-consistency-check.title-unable-to-check-the-rule-status',
+            'Unable to check the rule status'
+          )}
+          bottomSpacing={0}
+          topSpacing={2}
+        >
+          {stringifyErrorLike(waitState.error)}
+        </Alert>
+      );
+    }
+
+    // If groupConsistent is undefined, it means that the rule is still being checked and we don't know if it's consistent or not
+    // To prevent the inconsistency banner from blinking, we only show it if groupConsistent is false
+    if (groupConsistent === false) {
+      return (
+        <Stack direction="column" gap={0} ref={ref}>
+          <LoadingBar width={width} />
+          <Alert
+            title={t('alerting.rule-viewer.prometheus-consistency-check.alert-title', 'Update in progress')}
+            severity="info"
+          >
+            <Trans i18nKey="alerting.rule-viewer.prometheus-consistency-check.alert-message">
+              Alert rule has been added or updated. Changes may take up to a minute to appear on the Alert rules list
+              view.
+            </Trans>
+          </Alert>
+        </Stack>
+      );
+    }
 
-  if (isConsistent) {
     return null;
-  }
-
-  if (error) {
-    return (
-      <Alert title="Unable to check the rule status" bottomSpacing={0} topSpacing={2}>
-        {stringifyErrorLike(error)}
-      </Alert>
-    );
-  }
-
-  return (
-    <Stack direction="column" gap={0} ref={ref}>
-      <LoadingBar width={width} />
-      <Alert
-        title={t('alerting.rule-viewer.prometheus-consistency-check.alert-title', 'Update in progress')}
-        severity="info"
-      >
-        <Trans i18nKey="alerting.rule-viewer.prometheus-consistency-check.alert-message">
-          Alert rule has been updated. Changes may take up to a minute to appear on the Alert rules list view.
-        </Trans>
-      </Alert>
-    </Stack>
-  );
-}
+  },
+  { errorLogger: logError }
+);
 
 export const isErrorHealth = (health?: RuleHealth) => health === 'error' || health === 'err';
 
@@ -329,17 +409,18 @@ function isValidTab(tab: UrlQueryValue): tab is ActiveTab {
 function usePageNav(rule: CombinedRule) {
   const [activeTab, setActiveTab] = useActiveTab();
 
-  const { annotations, promRule } = rule;
+  const { annotations, promRule, rulerRule } = rule;
 
   const summary = annotations[Annotation.summary];
-  const isAlertType = isAlertingRule(promRule);
+  const isAlertType = prometheusRuleType.alertingRule(promRule);
   const numberOfInstance = isAlertType ? calculateTotalInstances(rule.instanceTotals) : undefined;
 
   const namespaceName = decodeGrafanaNamespace(rule.namespace).name;
   const groupName = rule.group.name;
 
-  const isGrafanaAlertRule = isGrafanaRulerRule(rule.rulerRule) && isAlertType;
-  const isRecordingRuleType = isRecordingRule(rule.promRule);
+  const isGrafanaAlertRule = rulerRuleType.grafana.alertingRule(rulerRule);
+  const isGrafanaRecordingRule = rulerRuleType.grafana.recordingRule(rulerRule);
+  const isRecordingRuleType = prometheusRuleType.recordingRule(promRule);
 
   const pageNav: NavModelItem = {
     ...defaultPageNav,
@@ -347,14 +428,14 @@ function usePageNav(rule: CombinedRule) {
     subTitle: summary,
     children: [
       {
-        text: 'Query and conditions',
+        text: t('alerting.use-page-nav.page-nav.text.query-and-conditions', 'Query and conditions'),
         active: activeTab === ActiveTab.Query,
         onClick: () => {
           setActiveTab(ActiveTab.Query);
         },
       },
       {
-        text: 'Instances',
+        text: t('alerting.use-page-nav.page-nav.text.instances', 'Instances'),
         active: activeTab === ActiveTab.Instances,
         onClick: () => {
           setActiveTab(ActiveTab.Instances);
@@ -363,7 +444,7 @@ function usePageNav(rule: CombinedRule) {
         hideFromTabs: isRecordingRuleType,
       },
       {
-        text: 'History',
+        text: t('alerting.use-page-nav.page-nav.text.history', 'History'),
         active: activeTab === ActiveTab.History,
         onClick: () => {
           setActiveTab(ActiveTab.History);
@@ -372,12 +453,20 @@ function usePageNav(rule: CombinedRule) {
         hideFromTabs: !isGrafanaAlertRule,
       },
       {
-        text: 'Details',
+        text: t('alerting.use-page-nav.page-nav.text.details', 'Details'),
         active: activeTab === ActiveTab.Details,
         onClick: () => {
           setActiveTab(ActiveTab.Details);
         },
       },
+      {
+        text: t('alerting.use-page-nav.page-nav.text.versions', 'Versions'),
+        active: activeTab === ActiveTab.VersionHistory,
+        onClick: () => {
+          setActiveTab(ActiveTab.VersionHistory);
+        },
+        hideFromTabs: !isGrafanaAlertRule && !isGrafanaRecordingRule,
+      },
     ],
     parentItem: {
       text: groupName,
@@ -399,20 +488,24 @@ function usePageNav(rule: CombinedRule) {
   };
 }
 
-const calculateTotalInstances = (stats: CombinedRule['instanceTotals']) => {
+export const calculateTotalInstances = (stats: AlertInstanceTotals) => {
   return chain(stats)
-    .pick([AlertInstanceTotalState.Alerting, AlertInstanceTotalState.Pending, AlertInstanceTotalState.Normal])
+    .pick([
+      AlertInstanceTotalState.Alerting,
+      AlertInstanceTotalState.Pending,
+      AlertInstanceTotalState.Recovering,
+      AlertInstanceTotalState.Normal,
+      AlertInstanceTotalState.NoData,
+      AlertInstanceTotalState.Error,
+    ])
     .values()
     .sum()
     .value();
 };
 
 const getStyles = () => ({
-  title: css({
-    display: 'flex',
-    alignItems: 'center',
-    gap: 8,
-    minWidth: 0,
+  url: css({
+    wordBreak: 'break-all',
   }),
 });
 
