@@ -7,6 +7,8 @@ export interface Line {
   current: GrafanaAlertStateWithReason;
   values?: Record<string, number>;
   labels?: Record<string, string>;
+  fingerprint?: string;
+  ruleUID?: string;
 }
 
 export interface LogRecord {
