@@ -1,4 +1,4 @@
-import { GrafanaNotifierType, NotifierDTO } from 'app/types';
+import { GrafanaNotifierType, NotifierDTO } from 'app/types/alerting';
 
 export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
   dingding: {
@@ -1607,10 +1607,7 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         placeholder: '',
         propertyName: 'url',
         selectOptions: null,
-        showWhen: {
-          field: '',
-          is: '',
-        },
+        showWhen: { field: '', is: '' },
         required: true,
         validationRule: '',
         secure: false,
@@ -1624,19 +1621,10 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         placeholder: '',
         propertyName: 'httpMethod',
         selectOptions: [
-          {
-            value: 'POST',
-            label: 'POST',
-          },
-          {
-            value: 'PUT',
-            label: 'PUT',
-          },
+          { value: 'POST', label: 'POST' },
+          { value: 'PUT', label: 'PUT' },
         ],
-        showWhen: {
-          field: '',
-          is: '',
-        },
+        showWhen: { field: '', is: '' },
         required: false,
         validationRule: '',
         secure: false,
@@ -1711,6 +1699,23 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         secure: true,
         dependsOn: '',
       },
+      {
+        element: 'key_value_map',
+        inputType: 'text',
+        label: 'Extra Headers',
+        description: 'Optionally provide extra headers to be used in the request.',
+        placeholder: '',
+        propertyName: 'headers',
+        selectOptions: null,
+        showWhen: {
+          field: '',
+          is: '',
+        },
+        required: false,
+        validationRule: '',
+        secure: false,
+        dependsOn: '',
+      },
       {
         element: 'input',
         inputType: 'text',
@@ -1730,7 +1735,7 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         dependsOn: '',
       },
       {
-        element: 'input',
+        element: 'textarea',
         inputType: 'text',
         label: 'Title',
         description: 'Templated title of the message.',
@@ -1763,13 +1768,477 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         secure: false,
         dependsOn: '',
       },
+      {
+        element: 'subform',
+        inputType: '',
+        label: 'Custom Payload',
+        description: "Optionally provide a templated payload. Overrides 'Message' and 'Title' field.",
+        placeholder: '',
+        propertyName: 'payload',
+        selectOptions: null,
+        showWhen: {
+          field: '',
+          is: '',
+        },
+        required: false,
+        validationRule: '',
+        secure: false,
+        dependsOn: '',
+        subformOptions: [
+          {
+            element: 'textarea',
+            inputType: '',
+            label: 'Payload Template',
+            description: 'Custom payload template.',
+            placeholder: '{{ template "webhook.default.payload" . }}',
+            propertyName: 'template',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: true,
+            validationRule: '',
+            secure: false,
+            dependsOn: '',
+          },
+          {
+            element: 'key_value_map',
+            inputType: 'text',
+            label: 'Payload Variables',
+            description:
+              'Optionally provide a variables to be used in the payload template. They will be available in the template as `.Vars.<variable_name>`.',
+            placeholder: '',
+            propertyName: 'vars',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: false,
+            dependsOn: '',
+          },
+        ],
+      },
+      {
+        element: 'subform',
+        inputType: '',
+        label: 'TLS',
+        description: 'TLS configuration options',
+        placeholder: '',
+        propertyName: 'tlsConfig',
+        selectOptions: null,
+        showWhen: {
+          field: '',
+          is: '',
+        },
+        required: false,
+        validationRule: '',
+        secure: false,
+        dependsOn: '',
+        subformOptions: [
+          {
+            element: 'checkbox',
+            inputType: '',
+            label: 'Disable certificate verification',
+            description: "Do not verify the server's certificate chain and host name.",
+            placeholder: '',
+            propertyName: 'insecureSkipVerify',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: false,
+            dependsOn: '',
+          },
+          {
+            element: 'textarea',
+            inputType: 'text',
+            label: 'CA Certificate',
+            description: "Certificate in PEM format to use when verifying the server's certificate chain.",
+            placeholder: '',
+            propertyName: 'caCertificate',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: true,
+            dependsOn: '',
+          },
+          {
+            element: 'textarea',
+            inputType: 'text',
+            label: 'Client Certificate',
+            description: 'Client certificate in PEM format to use when connecting to the server.',
+            placeholder: '',
+            propertyName: 'clientCertificate',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: true,
+            dependsOn: '',
+          },
+          {
+            element: 'textarea',
+            inputType: 'text',
+            label: 'Client Key',
+            description: 'Client key in PEM format to use when connecting to the server.',
+            placeholder: '',
+            propertyName: 'clientKey',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: true,
+            dependsOn: '',
+          },
+        ],
+      },
+      {
+        element: 'subform',
+        inputType: '',
+        label: 'HMAC Signature',
+        description: 'HMAC signature configuration options',
+        placeholder: '',
+        propertyName: 'hmacConfig',
+        selectOptions: null,
+        showWhen: {
+          field: '',
+          is: '',
+        },
+        required: false,
+        validationRule: '',
+        secure: false,
+        dependsOn: '',
+        subformOptions: [
+          {
+            element: 'input',
+            inputType: 'text',
+            label: 'Secret',
+            description: '',
+            placeholder: '',
+            propertyName: 'secret',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: true,
+            validationRule: '',
+            secure: true,
+            dependsOn: '',
+          },
+          {
+            element: 'input',
+            inputType: 'text',
+            label: 'Header',
+            description: 'The header in which the HMAC signature will be included.',
+            placeholder: 'X-Grafana-Alerting-Signature',
+            propertyName: 'header',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: false,
+            dependsOn: '',
+          },
+          {
+            element: 'input',
+            inputType: 'text',
+            label: 'Timestamp header',
+            description:
+              'If set, the timestamp will be included in the HMAC signature. The value should be the name of the header to use.',
+            placeholder: '',
+            propertyName: 'timestampHeader',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: false,
+            dependsOn: '',
+          },
+        ],
+      },
+      {
+        element: 'subform',
+        inputType: '',
+        label: 'HTTP Config',
+        description: 'Common HTTP client options.',
+        placeholder: '',
+        propertyName: 'http_config',
+        selectOptions: null,
+        showWhen: {
+          field: '',
+          is: '',
+        },
+        required: false,
+        validationRule: '',
+        secure: false,
+        dependsOn: '',
+        subformOptions: [
+          {
+            element: 'subform',
+            inputType: '',
+            label: 'OAuth2',
+            description: 'OAuth2 configuration options',
+            placeholder: '',
+            propertyName: 'oauth2',
+            selectOptions: null,
+            showWhen: {
+              field: '',
+              is: '',
+            },
+            required: false,
+            validationRule: '',
+            secure: false,
+            dependsOn: '',
+            subformOptions: [
+              {
+                element: 'input',
+                inputType: 'text',
+                label: 'Token URL',
+                description: 'URL for the access token endpoint.',
+                placeholder: '',
+                propertyName: 'token_url',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: true,
+                validationRule: '',
+                secure: false,
+                dependsOn: '',
+              },
+              {
+                element: 'input',
+                inputType: 'text',
+                label: 'Client ID',
+                description: 'Client ID to use when authenticating.',
+                placeholder: '',
+                propertyName: 'client_id',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: true,
+                validationRule: '',
+                secure: false,
+                dependsOn: '',
+              },
+              {
+                element: 'input',
+                inputType: 'text',
+                label: 'Client Secret',
+                description: 'Client secret to use when authenticating.',
+                placeholder: '',
+                propertyName: 'client_secret',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: true,
+                validationRule: '',
+                secure: true,
+                dependsOn: '',
+              },
+              {
+                element: 'string_array',
+                inputType: '',
+                label: 'Scopes',
+                description: 'Optional scopes to request when obtaining an access token.',
+                placeholder: '',
+                propertyName: 'scopes',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: false,
+                validationRule: '',
+                secure: false,
+                dependsOn: '',
+              },
+              {
+                element: 'key_value_map',
+                inputType: '',
+                label: 'Endpoint Parameters',
+                description: 'Optional parameters to append to the access token request.',
+                placeholder: '',
+                propertyName: 'endpoint_params',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: false,
+                validationRule: '',
+                secure: false,
+                dependsOn: '',
+              },
+              {
+                element: 'subform',
+                inputType: '',
+                label: 'TLS',
+                description: 'Optional TLS configuration options for OAuth2 requests.',
+                placeholder: '',
+                propertyName: 'tls_config',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: false,
+                validationRule: '',
+                secure: false,
+                dependsOn: '',
+                subformOptions: [
+                  {
+                    element: 'checkbox',
+                    inputType: '',
+                    label: 'Disable certificate verification',
+                    description: "Do not verify the server's certificate chain and host name.",
+                    placeholder: '',
+                    propertyName: 'insecureSkipVerify',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: false,
+                    dependsOn: '',
+                  },
+                  {
+                    element: 'textarea',
+                    inputType: 'text',
+                    label: 'CA Certificate',
+                    description: "Certificate in PEM format to use when verifying the server's certificate chain.",
+                    placeholder: '',
+                    propertyName: 'caCertificate',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: true,
+                    dependsOn: '',
+                  },
+                  {
+                    element: 'textarea',
+                    inputType: 'text',
+                    label: 'Client Certificate',
+                    description: 'Client certificate in PEM format to use when connecting to the server.',
+                    placeholder: '',
+                    propertyName: 'clientCertificate',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: true,
+                    dependsOn: '',
+                  },
+                  {
+                    element: 'textarea',
+                    inputType: 'text',
+                    label: 'Client Key',
+                    description: 'Client key in PEM format to use when connecting to the server.',
+                    placeholder: '',
+                    propertyName: 'clientKey',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: true,
+                    dependsOn: '',
+                  },
+                ],
+              },
+              {
+                element: 'subform',
+                inputType: '',
+                label: 'Proxy Config',
+                description: 'Optional proxy configuration.',
+                placeholder: '',
+                propertyName: 'proxy_config',
+                selectOptions: null,
+                showWhen: { field: '', is: '' },
+                required: false,
+                validationRule: '',
+                secure: false,
+                dependsOn: '',
+                subformOptions: [
+                  {
+                    element: 'input',
+                    inputType: 'text',
+                    label: 'Proxy URL',
+                    description: 'HTTP proxy server to use to connect to the targets.',
+                    placeholder: 'https://proxy.example.com',
+                    propertyName: 'proxy_url',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: false,
+                    dependsOn: '',
+                  },
+                  {
+                    element: 'checkbox',
+                    inputType: '',
+                    label: 'Proxy from environment',
+                    description: 'Use environment HTTP_PROXY, HTTPS_PROXY and NO_PROXY to determine proxies.',
+                    placeholder: '',
+                    propertyName: 'proxy_from_environment',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: false,
+                    dependsOn: '',
+                  },
+                  {
+                    element: 'input',
+                    inputType: 'text',
+                    label: 'No Proxy',
+                    description: 'Comma-separated list of addresses that should not use a proxy.',
+                    placeholder: 'example.com,1.2.3.4',
+                    propertyName: 'no_proxy',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: false,
+                    dependsOn: '',
+                  },
+                  {
+                    element: 'key_value_map',
+                    inputType: 'text',
+                    label: 'Proxy Connect Header',
+                    description: 'Optional headers to send to proxies during CONNECT requests.',
+                    placeholder: '',
+                    propertyName: 'proxy_connect_header',
+                    selectOptions: null,
+                    showWhen: { field: '', is: '' },
+                    required: false,
+                    validationRule: '',
+                    secure: false,
+                    dependsOn: '',
+                  },
+                ],
+              },
+            ],
+          },
+        ],
+      },
     ],
   },
   oncall: {
     type: 'oncall',
-    name: 'Grafana OnCall',
-    heading: 'Grafana OnCall settings',
-    description: 'Sends notifications to Grafana OnCall',
+    name: 'Grafana IRM',
+    heading: 'Grafana IRM settings',
+    description: 'Sends notifications to Grafana IRM',
     info: '',
     options: [
       {
@@ -2507,7 +2976,7 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         inputType: 'text',
         label: 'Message format',
         description:
-          "The format of the message to be sent. If set to 'json', the message will be sent as a JSON object. If set to 'text', the message will be sent as a plain text string. By default json is used.",
+          "If set to 'json', the notification message is the default JSON payload, and the Message field sets only the message field in the payload. If set to 'text', the Message field defines the entire payload. The default is 'json'.",
         placeholder: 'json',
         propertyName: 'messageFormat',
         selectOptions: [
@@ -2550,7 +3019,8 @@ export const grafanaAlertNotifiers: Record<GrafanaNotifierType, NotifierDTO> = {
         element: 'textarea',
         inputType: '',
         label: 'Message',
-        description: '',
+        description:
+          "In 'json' Message format, sets the message field of the default JSON payload. In 'text' Message format, defines the entire payload.",
         placeholder: '{{ template "default.message" . }}',
         propertyName: 'message',
         selectOptions: null,
