@@ -1,6 +1,6 @@
 import { Badge } from '@grafana/ui';
 import { AnnoKeyManagerIdentity, AnnoKeyManagerKind, ManagerKind } from 'app/features/apiserver/types';
-import { DashboardMeta } from 'app/types';
+import { DashboardMeta } from 'app/types/dashboard';
 
 export default function ManagedDashboardNavBarBadge({ meta }: { meta: DashboardMeta }) {
   const obj = meta.k8s;
@@ -14,10 +14,13 @@ export default function ManagedDashboardNavBarBadge({ meta }: { meta: DashboardM
   switch (kind) {
     case ManagerKind.Terraform:
       text = 'Terraform';
+      break;
     case ManagerKind.Kubectl:
       text = 'Kubectl';
+      break;
     case ManagerKind.Plugin:
       text = `Plugin: ${id}`;
+      break;
   }
-  return <Badge color="darkgrey" icon="exchange-alt" text={text} key="provisioned-dashboard-button-badge" />;
+  return <Badge color="purple" icon="exchange-alt" tooltip={text} key="provisioned-dashboard-button-badge" />;
 }
