@@ -1,7 +1,7 @@
 import { Registry } from '@grafana/data';
 
+import { AutoGridLayoutManager } from '../layout-auto-grid/AutoGridLayoutManager';
 import { DefaultGridLayoutManager } from '../layout-default/DefaultGridLayoutManager';
-import { ResponsiveGridLayoutManager } from '../layout-responsive-grid/ResponsiveGridLayoutManager';
 import { RowsLayoutManager } from '../layout-rows/RowsLayoutManager';
 import { TabsLayoutManager } from '../layout-tabs/TabsLayoutManager';
 import { LayoutRegistryItem } from '../types/LayoutRegistryItem';
@@ -9,7 +9,7 @@ import { LayoutRegistryItem } from '../types/LayoutRegistryItem';
 export const layoutRegistry: Registry<LayoutRegistryItem> = new Registry<LayoutRegistryItem>(() => {
   return [
     DefaultGridLayoutManager.descriptor,
-    ResponsiveGridLayoutManager.descriptor,
+    AutoGridLayoutManager.descriptor,
     RowsLayoutManager.descriptor,
     TabsLayoutManager.descriptor,
   ];
