@@ -4,8 +4,6 @@ import { IconName } from '@grafana/data';
 import { SceneObject } from '@grafana/scenes';
 import { OptionsPaneCategoryDescriptor } from 'app/features/dashboard/components/PanelEditor/OptionsPaneCategoryDescriptor';
 
-import { MultiSelectedEditableDashboardElement } from './MultiSelectedEditableDashboardElement';
-
 /**
  * Interface for elements that have options
  */
@@ -21,33 +19,69 @@ export interface EditableDashboardElement {
   /**
    * Hook that returns edit pane options
    */
-  useEditPaneOptions(): OptionsPaneCategoryDescriptor[];
+  useEditPaneOptions(isNewElement: boolean): OptionsPaneCategoryDescriptor[];
 
   /**
    * Panel Actions
    **/
   renderActions?(): ReactNode;
 
+  /**
+   * Supports delete action
+   */
+  onDelete?(): void;
+
+  /**
+   * Should confirm delete action
+   */
+  onConfirmDelete?(): void;
+
+  /**
+   * Supports duplicate action
+   */
+  onDuplicate?(): void;
+
+  /**
+   * Supports copy action
+   */
+  onCopy?(): void;
+
   /**
    * creates a new multi-selection element from a list of selected items
    */
-  createMultiSelectedElement?(items: SceneObject[]): MultiSelectedEditableDashboardElement;
+  createMultiSelectedElement?(elements: this[]): EditableDashboardElement;
 
   /**
-   * Return custom title for the edit panel header
+   * scroll element into view (when selected from outline)
    */
-  renderTitle?(): ReactNode;
+  scrollIntoView?(): void;
 
   /**
-   * determines if first edit panel header can be collapsed
+   * Used to sync row collapsed state with outline
    */
-  isOpenable?: Readonly<boolean>;
+  getCollapsedState?(): boolean;
+
+  /**
+   * Used to sync row collapsed state with outline
+   */
+  setCollapsedState?(collapsed: boolean): void;
+
+  /**
+   * Used to change name from outline
+   */
+  onChangeName?(name: string): { errorMessage?: string } | void;
+
+  /**
+   * Container objects can have children
+   */
+  getOutlineChildren?(): SceneObject[];
 }
 
 export interface EditableDashboardElementInfo {
-  name: string;
-  typeId: string;
+  instanceName: string;
+  typeName: string;
   icon: IconName;
+  isHidden?: boolean;
 }
 
 export function isEditableDashboardElement(obj: object): obj is EditableDashboardElement {
