@@ -1,10 +1,10 @@
-import { BaseQueryFn, createApi } from '@reduxjs/toolkit/query/react';
-import { lastValueFrom } from 'rxjs';
+import { createApi } from '@reduxjs/toolkit/query/react';
 
-import { BackendSrvRequest, config, FetchError, getBackendSrv, isFetchError } from '@grafana/runtime/src';
+import { t } from '@grafana/i18n';
+import { config, FetchError, isFetchError } from '@grafana/runtime';
+import { createBaseQuery } from 'app/api/createBaseQuery';
 import { notifyApp } from 'app/core/actions';
 import { createErrorNotification, createSuccessNotification } from 'app/core/copy/appNotification';
-import { t } from 'app/core/internationalization';
 import {
   PublicDashboard,
   PublicDashboardSettings,
@@ -12,46 +12,24 @@ import {
   SessionDashboard,
   SessionUser,
 } from 'app/features/dashboard/components/ShareModal/SharePublicDashboard/SharePublicDashboardUtils';
-import { DashboardModel } from 'app/features/dashboard/state';
+import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
 import { DashboardScene } from 'app/features/dashboard-scene/scene/DashboardScene';
 import {
   PublicDashboardListWithPagination,
   PublicDashboardListWithPaginationResponse,
 } from 'app/features/manage-dashboards/types';
 
-type ReqOptions = {
-  manageError?: (err: unknown) => { error: unknown };
-  showErrorAlert?: boolean;
-};
-
 function isFetchBaseQueryError(error: unknown): error is { error: FetchError } {
   return typeof error === 'object' && error != null && 'error' in error;
 }
 
-const backendSrvBaseQuery =
-  ({ baseUrl }: { baseUrl: string }): BaseQueryFn<BackendSrvRequest & ReqOptions> =>
-  async (requestOptions) => {
-    try {
-      const { data: responseData, ...meta } = await lastValueFrom(
-        getBackendSrv().fetch({
-          ...requestOptions,
-          url: baseUrl + requestOptions.url,
-          showErrorAlert: requestOptions.showErrorAlert,
-        })
-      );
-      return { data: responseData, meta };
-    } catch (error) {
-      return requestOptions.manageError ? requestOptions.manageError(error) : { error };
-    }
-  };
-
-const getConfigError = (err: unknown) => ({
+export const getConfigError = (err: unknown) => ({
   error: isFetchError(err) && err.data.messageId !== 'publicdashboards.notFound' ? err : null,
 });
 
 export const publicDashboardApi = createApi({
   reducerPath: 'publicDashboardApi',
-  baseQuery: backendSrvBaseQuery({ baseUrl: '/api' }),
+  baseQuery: createBaseQuery({ baseURL: '/api' }),
   tagTypes: ['PublicDashboard', 'AuditTablePublicDashboard', 'UsersWithActiveSessions', 'ActiveUserDashboards'],
   refetchOnMountOrArgChange: true,
   endpoints: (builder) => ({
@@ -81,7 +59,7 @@ export const publicDashboardApi = createApi({
         return {
           url: `/dashboards/uid/${dashUid}/public-dashboards`,
           method: 'POST',
-          data: params.payload,
+          body: params.payload,
         };
       },
       async onQueryStarted({ dashboard, payload: { share } }, { dispatch, queryFulfilled }) {
@@ -121,7 +99,7 @@ export const publicDashboardApi = createApi({
         return {
           url: `/dashboards/uid/${dashUid}/public-dashboards/${payload.uid}`,
           method: 'PATCH',
-          data: payload,
+          body: payload,
         };
       },
       async onQueryStarted({ dashboard }, { dispatch, queryFulfilled }) {
@@ -153,7 +131,7 @@ export const publicDashboardApi = createApi({
         return {
           url: `/dashboards/uid/${dashUid}/public-dashboards/${payload.uid}`,
           method: 'PATCH',
-          data: payload,
+          body: payload,
         };
       },
       async onQueryStarted({ dashboard, payload: { isEnabled } }, { dispatch, queryFulfilled }) {
@@ -193,7 +171,7 @@ export const publicDashboardApi = createApi({
         return {
           url: `/dashboards/uid/${dashUid}/public-dashboards/${payload.uid}`,
           method: 'PATCH',
-          data: payload,
+          body: payload,
         };
       },
       async onQueryStarted({ dashboard, payload: { share } }, { dispatch, queryFulfilled }) {
