@@ -12,17 +12,18 @@ import { OptionsPaneItemOverrides } from './OptionsPaneItemOverrides';
 import { OptionPaneItemOverrideInfo } from './types';
 
 export interface OptionsPaneItemInfo {
-  title: string;
+  title?: string;
   value?: any;
   description?: string;
   popularRank?: number;
-  render: () => React.ReactElement;
+  render: (descriptor: OptionsPaneItemDescriptor) => React.ReactElement;
   skipField?: boolean;
   showIf?: () => boolean;
   /** Hook for controlling visibility */
   useShowIf?: () => boolean;
   overrides?: OptionPaneItemOverrideInfo[];
   addon?: ReactNode;
+  id?: string;
 }
 
 /**
@@ -56,7 +57,7 @@ interface OptionsPaneItemProps {
 }
 
 function OptionsPaneItem({ itemDescriptor, searchQuery }: OptionsPaneItemProps) {
-  const { title, description, render, skipField } = itemDescriptor.props;
+  const { title, description, id, render, skipField } = itemDescriptor.props;
   const key = `${itemDescriptor.parent.props.id} ${title}`;
   const showIf = itemDescriptor.useShowIf();
 
@@ -65,7 +66,7 @@ function OptionsPaneItem({ itemDescriptor, searchQuery }: OptionsPaneItemProps)
   }
 
   if (skipField) {
-    return render();
+    return render(itemDescriptor);
   }
 
   return (
@@ -74,14 +75,19 @@ function OptionsPaneItem({ itemDescriptor, searchQuery }: OptionsPaneItemProps)
       description={description}
       key={key}
       aria-label={selectors.components.PanelEditor.OptionsPane.fieldLabel(key)}
+      htmlFor={id}
     >
-      {render()}
+      {render(itemDescriptor)}
     </Field>
   );
 }
 
 function renderOptionLabel(itemDescriptor: OptionsPaneItemDescriptor, searchQuery?: string): ReactNode {
-  const { title, description, overrides, addon } = itemDescriptor.props;
+  const { title, description, overrides, id, addon } = itemDescriptor.props;
+
+  if (!title) {
+    return null;
+  }
 
   if (!searchQuery) {
     // Do not render label for categories with only one child
@@ -89,7 +95,7 @@ function renderOptionLabel(itemDescriptor: OptionsPaneItemDescriptor, searchQuer
       return null;
     }
 
-    return <OptionPaneLabel title={title} description={description} overrides={overrides} addon={addon} />;
+    return <OptionPaneLabel title={title} description={description} overrides={overrides} addon={addon} htmlFor={id} />;
   }
 
   const categories: React.ReactNode[] = [];
@@ -103,7 +109,7 @@ function renderOptionLabel(itemDescriptor: OptionsPaneItemDescriptor, searchQuer
   }
 
   return (
-    <Label description={description && highlightWord(description, searchQuery)} category={categories}>
+    <Label description={description && highlightWord(description, searchQuery)} category={categories} htmlFor={id}>
       {highlightWord(title, searchQuery)}
       {overrides && overrides.length > 0 && <OptionsPaneItemOverrides overrides={overrides} />}
     </Label>
@@ -119,13 +125,14 @@ interface OptionPanelLabelProps {
   description?: string;
   overrides?: OptionPaneItemOverrideInfo[];
   addon: ReactNode;
+  htmlFor?: string;
 }
 
-function OptionPaneLabel({ title, description, overrides, addon }: OptionPanelLabelProps) {
+function OptionPaneLabel({ title, description, overrides, addon, htmlFor }: OptionPanelLabelProps) {
   const styles = useStyles2(getLabelStyles);
   return (
     <div className={styles.container}>
-      <Label description={description}>
+      <Label description={description} htmlFor={htmlFor}>
         {title}
         {overrides && overrides.length > 0 && <OptionsPaneItemOverrides overrides={overrides} />}
       </Label>
