@@ -19,17 +19,21 @@ import {
 } from '@grafana/data';
 import { PromQuery } from '@grafana/prometheus';
 import { RefreshEvent, TimeRangeUpdatedEvent, config } from '@grafana/runtime';
-import { Dashboard, DashboardLink } from '@grafana/schema';
+import { Dashboard, DashboardLink, VariableModel } from '@grafana/schema';
 import { DEFAULT_ANNOTATION_COLOR } from '@grafana/ui';
 import { GRID_CELL_HEIGHT, GRID_CELL_VMARGIN, GRID_COLUMN_COUNT, REPEAT_DIR_VERTICAL } from 'app/core/constants';
 import { contextSrv } from 'app/core/services/context_srv';
 import { sortedDeepCloneWithoutNulls } from 'app/core/utils/object';
-import { isAngularDatasourcePluginAndNotHidden } from 'app/features/plugins/angularDeprecation/utils';
 import { variableAdapters } from 'app/features/variables/adapters';
 import { onTimeRangeUpdated } from 'app/features/variables/state/actions';
 import { GetVariables, getVariablesByKey } from 'app/features/variables/state/selectors';
-import { CoreEvents, DashboardMeta, KioskMode } from 'app/types';
-import { DashboardMetaChangedEvent, DashboardPanelsChangedEvent, RenderEvent } from 'app/types/events';
+import { DashboardMeta } from 'app/types/dashboard';
+import {
+  DashboardMetaChangedEvent,
+  DashboardPanelsChangedEvent,
+  RenderEvent,
+  templateVariableValueUpdated,
+} from 'app/types/events';
 
 import { appEvents } from '../../../core/core';
 import { dispatch } from '../../../store/store';
@@ -44,7 +48,7 @@ import { getTimeSrv } from '../services/TimeSrv';
 import { mergePanels, PanelMergeInfo } from '../utils/panelMerge';
 
 import { DashboardMigrator } from './DashboardMigrator';
-import { explicitlyControlledMigrationPanels, PanelModel } from './PanelModel';
+import { PanelModel } from './PanelModel';
 import { TimeModel } from './TimeModel';
 import { deleteScopeVars, isOnTheSameGridRow } from './utils';
 
@@ -56,6 +60,12 @@ export interface CloneOptions {
 
 export type DashboardLinkType = 'link' | 'dashboards';
 
+/** @experimental */
+export interface ScopeMeta {
+  trait: string;
+  groups: string[];
+}
+
 export class DashboardModel implements TimeModel {
   /** @deprecated use UID */
   id: any;
@@ -87,6 +97,7 @@ export class DashboardModel implements TimeModel {
   panelInEdit?: PanelModel;
   panelInView?: PanelModel;
   fiscalYearStartMonth?: number;
+  scopeMeta?: ScopeMeta;
   private panelsAffectedByVariableChange: number[] | null;
   private appEventsSubscription: Subscription;
   private lastRefresh: number;
@@ -133,7 +144,7 @@ export class DashboardModel implements TimeModel {
     this.events = new EventBusSrv();
     this.id = data.id || null;
     // UID is not there for newly created dashboards
-    this.uid = data.uid || null;
+    this.uid = data.uid || meta?.uid || null;
     this.revision = data.revision ?? undefined;
     this.title = data.title ?? 'No Title';
     this.description = data.description;
@@ -145,7 +156,7 @@ export class DashboardModel implements TimeModel {
     this.time = data.time ?? { from: 'now-6h', to: 'now' };
     this.timepicker = data.timepicker ?? {};
     this.liveNow = data.liveNow;
-    this.templating = this.ensureListExist(data.templating);
+    this.templating = this.removeNullValuesFromVariables(this.ensureListExist(data.templating));
     this.annotations = this.ensureListExist(data.annotations);
     this.refresh = data.refresh;
     this.snapshot = data.snapshot;
@@ -155,6 +166,8 @@ export class DashboardModel implements TimeModel {
     this.links = data.links ?? [];
     this.gnetId = data.gnetId || null;
     this.panels = map(data.panels ?? [], (panelData) => new PanelModel(panelData));
+    // @ts-expect-error - experimental and it's not included in the schema
+    this.scopeMeta = data.scopeMeta;
     // Deep clone original dashboard to avoid mutations by object reference
     this.originalDashboard = cloneDeep(data);
     this.originalTemplating = cloneDeep(this.templating);
@@ -277,6 +290,8 @@ export class DashboardModel implements TimeModel {
    *
    * @internal and experimental
    */
+  // TODO: remove this as it's not being used anymore
+  // Also remove public/app/features/dashboard/utils/panelMerge.ts
   updatePanels(panels: IPanelModel[]): PanelMergeInfo {
     const info = mergePanels(this.panels, panels ?? []);
     if (info.changed) {
@@ -471,6 +486,28 @@ export class DashboardModel implements TimeModel {
     }
   }
 
+  private removeNullValuesFromVariables(templating: { list: VariableModel[] }) {
+    if (!templating.list.length) {
+      return templating;
+    }
+
+    for (const variable of templating.list) {
+      if (variable.current) {
+        // this is a safeguard for null value that breaks scenes dashboards.
+        //    expecting error at .includes(null) in order to not adjust
+        //    VariableOption type to avoid breaking changes
+        if (
+          variable.current.value === null ||
+          //@ts-expect-error
+          (Array.isArray(variable.current.value) && variable.current.value.includes(null))
+        ) {
+          variable.current = undefined;
+        }
+      }
+    }
+    return templating;
+  }
+
   private ensureListExist(data: any = {}) {
     data.list ??= [];
     return data;
@@ -1108,7 +1145,7 @@ export class DashboardModel implements TimeModel {
     let visibleHeight = viewHeight - navbarHeight - margin;
 
     // add back navbar height
-    if (kioskMode && kioskMode !== KioskMode.TV) {
+    if (kioskMode) {
       visibleHeight += navbarHeight;
     }
 
@@ -1123,7 +1160,7 @@ export class DashboardModel implements TimeModel {
 
   templateVariableValueUpdated() {
     this.processRepeats();
-    this.events.emit(CoreEvents.templateVariableValueUpdated);
+    this.events.emit(templateVariableValueUpdated);
   }
 
   getPanelByUrlId(panelUrlId: string) {
@@ -1156,7 +1193,14 @@ export class DashboardModel implements TimeModel {
   toggleExemplarsForAll() {
     for (const panel of this.panels) {
       for (const target of panel.targets) {
-        if (!(target.datasource && target.datasource.type === 'prometheus')) {
+        if (
+          !(
+            target.datasource &&
+            (target.datasource.type === 'prometheus' ||
+              target.datasource.type === 'grafana-amazonprometheus-datasource' ||
+              target.datasource.type === 'grafana-azureprometheus-datasource')
+          )
+        ) {
           continue;
         }
 
@@ -1289,22 +1333,6 @@ export class DashboardModel implements TimeModel {
   getOriginalDashboard() {
     return this.originalDashboard;
   }
-
-  hasAngularPlugins(): boolean {
-    return this.panels.some((panel) => {
-      // Return false for plugins that are angular but have angular.hideDeprecation = false
-      // We cannot use panel.plugin.isAngularPlugin() because panel.plugin may not be initialized at this stage.
-      // We also have to check for old core angular plugins (explicitlyControlledMigrationPanels).
-      const isAngularPanel =
-        (config.panels[panel.type]?.angular?.detected || explicitlyControlledMigrationPanels.includes(panel.type)) &&
-        !config.panels[panel.type]?.angular?.hideDeprecation;
-      let isAngularDs = false;
-      if (panel.datasource?.uid) {
-        isAngularDs = isAngularDatasourcePluginAndNotHidden(panel.datasource?.uid);
-      }
-      return isAngularPanel || isAngularDs;
-    });
-  }
 }
 
 function isPanelWithLegend(panel: PanelModel): panel is PanelModel & Pick<Required<PanelModel>, 'legend'> {
