@@ -1,6 +1,5 @@
-import React from 'react';
-
 import { PluginState } from '@grafana/data';
+import { Trans } from '@grafana/i18n';
 import { PluginStateInfo } from 'app/features/plugins/components/PluginStateInfo';
 
 export type Props = {
@@ -10,10 +9,12 @@ export type Props = {
 export function DataSourcePluginState({ state }: Props) {
   return (
     <div className="gf-form">
-      <label className="gf-form-label width-10">Plugin state</label>
-      <label className="gf-form-label gf-form-label--transparent">
+      <div className="gf-form-label width-10">
+        <Trans i18nKey="datasources.data-source-plugin-state.plugin-state">Plugin state</Trans>
+      </div>
+      <div className="gf-form-label gf-form-label--transparent">
         <PluginStateInfo state={state} />
-      </label>
+      </div>
     </div>
   );
 }
