@@ -1,11 +1,12 @@
 import { css, cx } from '@emotion/css';
-import React, { memo, CSSProperties } from 'react';
-import SVG from 'react-inlinesvg';
+import { memo, CSSProperties } from 'react';
+import * as React from 'react';
 import AutoSizer from 'react-virtualized-auto-sizer';
 import { areEqual, FixedSizeGrid as Grid } from 'react-window';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { useTheme2, stylesFactory } from '@grafana/ui';
+import { useStyles2 } from '@grafana/ui';
+import { SanitizedSVG } from 'app/core/components/SVG/SanitizedSVG';
 
 import { ResourceItem } from './FolderPickerTab';
 
@@ -21,13 +22,12 @@ interface CellProps {
   };
 }
 
-function Cell(props: CellProps) {
+const MemoizedCell = memo(function Cell(props: CellProps) {
   const { columnIndex, rowIndex, style, data } = props;
   const { cards, columnCount, onChange, selected } = data;
   const singleColumnIndex = columnIndex + rowIndex * columnCount;
   const card = cards[singleColumnIndex];
-  const theme = useTheme2();
-  const styles = getStyles(theme);
+  const styles = useStyles2(getStyles);
 
   return (
     <div style={style}>
@@ -36,65 +36,25 @@ function Cell(props: CellProps) {
           key={card.value}
           className={selected === card.value ? cx(styles.card, styles.selected) : styles.card}
           onClick={() => onChange(card.value)}
+          onKeyDown={(e: React.KeyboardEvent) => {
+            if (e.key === 'Enter') {
+              onChange(card.value);
+            }
+          }}
+          role="button"
+          tabIndex={0}
         >
           {card.imgUrl.endsWith('.svg') ? (
-            <SVG src={card.imgUrl} className={styles.img} />
+            <SanitizedSVG src={card.imgUrl} className={styles.img} />
           ) : (
-            <img src={card.imgUrl} className={styles.img} />
+            <img src={card.imgUrl} alt="" className={styles.img} />
           )}
           <h6 className={styles.text}>{card.label.slice(0, -4)}</h6>
         </div>
       )}
     </div>
   );
-}
-
-const getStyles = stylesFactory((theme: GrafanaTheme2) => {
-  return {
-    card: css`
-      display: inline-block;
-      width: 90px;
-      height: 90px;
-      margin: 0.75rem;
-      margin-left: 15px;
-      text-align: center;
-      cursor: pointer;
-      position: relative;
-      background-color: transparent;
-      border: 1px solid transparent;
-      border-radius: 8px;
-      padding-top: 6px;
-      :hover {
-        border-color: ${theme.colors.action.hover};
-        box-shadow: ${theme.shadows.z2};
-      }
-    `,
-    selected: css`
-      border: 2px solid ${theme.colors.primary.main};
-      :hover {
-        border-color: ${theme.colors.primary.main};
-      }
-    `,
-    img: css`
-      width: 40px;
-      height: 40px;
-      object-fit: cover;
-      vertical-align: middle;
-      fill: ${theme.colors.text.primary};
-    `,
-    text: css`
-      color: ${theme.colors.text.primary};
-      white-space: nowrap;
-      font-size: 12px;
-      text-overflow: ellipsis;
-      display: block;
-      overflow: hidden;
-    `,
-    grid: css`
-      border: 1px solid ${theme.colors.border.medium};
-    `,
-  };
-});
+}, areEqual);
 
 interface CardProps {
   onChange: (value: string) => void;
@@ -104,8 +64,7 @@ interface CardProps {
 
 export const ResourceCards = (props: CardProps) => {
   const { onChange, cards, value } = props;
-  const theme = useTheme2();
-  const styles = getStyles(theme);
+  const styles = useStyles2(getStyles);
 
   return (
     <AutoSizer defaultWidth={680}>
@@ -125,10 +84,55 @@ export const ResourceCards = (props: CardProps) => {
             itemData={{ cards, columnCount, onChange, selected: value }}
             className={styles.grid}
           >
-            {memo(Cell, areEqual)}
+            {MemoizedCell}
           </Grid>
         );
       }}
     </AutoSizer>
   );
 };
+
+const getStyles = (theme: GrafanaTheme2) => ({
+  card: css({
+    display: 'inline-block',
+    width: '90px',
+    height: '90px',
+    margin: '0.75rem',
+    marginLeft: '15px',
+    textAlign: 'center',
+    cursor: 'pointer',
+    position: 'relative',
+    backgroundColor: 'transparent',
+    border: '1px solid transparent',
+    borderRadius: theme.shape.radius.default,
+    paddingTop: '6px',
+    ':hover': {
+      borderColor: theme.colors.action.hover,
+      boxShadow: theme.shadows.z2,
+    },
+  }),
+  selected: css({
+    border: `2px solid ${theme.colors.primary.main}`,
+    ':hover': {
+      borderColor: theme.colors.primary.main,
+    },
+  }),
+  img: css({
+    width: '40px',
+    height: '40px',
+    objectFit: 'cover',
+    verticalAlign: 'middle',
+    fill: theme.colors.text.primary,
+  }),
+  text: css({
+    color: theme.colors.text.primary,
+    whiteSpace: 'nowrap',
+    fontSize: '12px',
+    textOverflow: 'ellipsis',
+    display: 'block',
+    overflow: 'hidden',
+  }),
+  grid: css({
+    border: `1px solid ${theme.colors.border.medium}`,
+  }),
+});
