@@ -17,7 +17,6 @@ import {
 export async function getPluginDetails(id: string): Promise<CatalogPluginDetails> {
   const remote = await getRemotePlugin(id);
   const isPublished = Boolean(remote);
-
   const [localPlugins, versions, localReadme, localChangelog] = await Promise.all([
     getLocalPlugins(),
     getPluginVersions(id, isPublished),
@@ -36,7 +35,16 @@ export async function getPluginDetails(id: string): Promise<CatalogPluginDetails
     versions,
     statusContext: remote?.statusContext ?? '',
     iam: remote?.json?.iam,
-    changelog: localChangelog || remote?.changelog,
+    lastCommitDate: remote?.lastCommitDate,
+    changelog: remote?.changelog || localChangelog,
+    licenseUrl: remote?.licenseUrl,
+    documentationUrl: remote?.documentationUrl,
+    sponsorshipUrl: remote?.sponsorshipUrl,
+    repositoryUrl: remote?.repositoryUrl,
+    raiseAnIssueUrl: remote?.raiseAnIssueUrl,
+    signatureType: local?.signatureType || (remote?.signatureType !== '' ? remote?.signatureType : undefined),
+    signature: local?.signature,
+    screenshots: remote?.json?.info.screenshots || local?.info.screenshots,
   };
 }
 
@@ -92,8 +100,10 @@ async function getPluginVersions(id: string, isPublished: boolean): Promise<Vers
     return (versions.items || []).map((v) => ({
       version: v.version,
       createdAt: v.createdAt,
+      updatedAt: v.updatedAt,
       isCompatible: v.isCompatible,
       grafanaDependency: v.grafanaDependency,
+      angularDetected: v.angularDetected,
     }));
   } catch (error) {
     if (isFetchError(error)) {
@@ -122,7 +132,6 @@ async function getLocalPluginChangelog(id: string): Promise<string> {
   try {
     const markdown: string = await getBackendSrv().get(`${API_ROOT}/${id}/markdown/CHANGELOG`);
     const markdownAsHtml = markdown ? renderMarkdown(markdown) : '';
-
     return markdownAsHtml;
   } catch (error) {
     if (isFetchError(error)) {
@@ -157,13 +166,19 @@ export async function getProvisionedPlugins(): Promise<ProvisionedPlugin[]> {
   return provisionedPlugins.map((plugin) => ({ slug: plugin.type }));
 }
 
-export async function installPlugin(id: string) {
+export async function installPlugin(id: string, version?: string) {
   // This will install the latest compatible version based on the logic
   // on the backend.
-  return await getBackendSrv().post(`${API_ROOT}/${id}/install`, undefined, {
-    // Error is displayed in the page
-    showErrorAlert: false,
-  });
+  return await getBackendSrv().post(
+    `${API_ROOT}/${id}/install`,
+    {
+      version,
+    },
+    {
+      // Error is displayed in the page
+      showErrorAlert: false,
+    }
+  );
 }
 
 export async function uninstallPlugin(id: string) {
