@@ -1,31 +1,28 @@
-// Libraries
 import classNames from 'classnames';
-import { cloneDeep, filter, has, uniqBy, uniqueId } from 'lodash';
+import { cloneDeep, filter, uniqBy, uniqueId } from 'lodash';
 import pluralize from 'pluralize';
-import * as React from 'react';
 import { PureComponent, ReactNode } from 'react';
 
-// Utils & Services
 import {
   CoreApp,
   DataSourceApi,
   DataSourceInstanceSettings,
   DataSourcePluginContextProvider,
+  PluginExtensionQueryEditorRowAdaptiveTelemetryV1Context,
   EventBusExtended,
-  EventBusSrv,
   HistoryItem,
   LoadingState,
   PanelData,
-  PanelEvents,
   QueryResultMetaNotice,
   TimeRange,
   getDataSourceRef,
-  toLegacyResponseData,
+  PluginExtensionPoints,
 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { AngularComponent, getAngularLoader, getDataSourceSrv, reportInteraction } from '@grafana/runtime';
+import { Trans, t } from '@grafana/i18n';
+import { getDataSourceSrv, renderLimitedComponents, reportInteraction, usePluginComponents } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
-import { Badge, ErrorBoundaryAlert } from '@grafana/ui';
+import { Badge, ErrorBoundaryAlert, List } from '@grafana/ui';
 import { OperationRowHelp } from 'app/core/components/QueryOperationRow/OperationRowHelp';
 import {
   QueryOperationAction,
@@ -35,10 +32,6 @@ import {
   QueryOperationRow,
   QueryOperationRowRenderProps,
 } from 'app/core/components/QueryOperationRow/QueryOperationRow';
-import { Trans, t } from 'app/core/internationalization';
-import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
-import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
-import { PanelModel } from 'app/features/dashboard/state/PanelModel';
 
 import { useQueryLibraryContext } from '../../explore/QueryLibrary/QueryLibraryContext';
 
@@ -59,6 +52,7 @@ export interface Props<TQuery extends DataQuery> {
   onAddQuery: (query: TQuery) => void;
   onRemoveQuery: (query: TQuery) => void;
   onChange: (query: TQuery) => void;
+  onReplace?: (query: DataQuery) => void;
   onRunQuery: () => void;
   visualization?: ReactNode;
   hideHideQueryButton?: boolean;
@@ -70,6 +64,7 @@ export interface Props<TQuery extends DataQuery> {
   onQueryCopied?: () => void;
   onQueryRemoved?: () => void;
   onQueryToggled?: (queryStatus?: boolean | undefined) => void;
+  onQueryReplacedFromLibrary?: () => void;
   collapsable?: boolean;
   hideRefId?: boolean;
 }
@@ -79,22 +74,17 @@ interface State<TQuery extends DataQuery> {
   queriedDataSourceIdentifier?: string | null;
   datasource: DataSourceApi<TQuery> | null;
   datasourceUid?: string | null;
-  hasTextEditMode: boolean;
   data?: PanelData;
   isOpen?: boolean;
   showingHelp: boolean;
 }
 
 export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Props<TQuery>, State<TQuery>> {
-  element: HTMLElement | null = null;
-  angularScope: AngularQueryComponentScope<TQuery> | null = null;
-  angularQueryEditor: AngularComponent | null = null;
   dataSourceSrv = getDataSourceSrv();
   id = '';
 
   state: State<TQuery> = {
     datasource: null,
-    hasTextEditMode: false,
     data: undefined,
     isOpen: true,
     showingHelp: false,
@@ -109,46 +99,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
     this.loadDatasource();
   }
 
-  componentWillUnmount() {
-    if (this.angularQueryEditor) {
-      this.angularQueryEditor.destroy();
-    }
-  }
-
-  getAngularQueryComponentScope(): AngularQueryComponentScope<TQuery> {
-    const { query, queries } = this.props;
-    const { datasource } = this.state;
-    const panel = new PanelModel({ targets: queries });
-    const dashboard = {} as DashboardModel;
-
-    const me = this;
-
-    return {
-      datasource: datasource,
-      target: query,
-      panel: panel,
-      dashboard: dashboard,
-      refresh: () => {
-        // Old angular editors modify the query model and just call refresh
-        // Important that this use this.props here so that as this function is only created on mount and it's
-        // important not to capture old prop functions in this closure
-
-        // the "hide" attribute of the queries can be changed from the "outside",
-        // it will be applied to "this.props.query.hide", but not to "query.hide".
-        // so we have to apply it.
-        if (query.hide !== me.props.query.hide) {
-          query.hide = me.props.query.hide;
-        }
-
-        this.props.onChange(query);
-        this.props.onRunQuery();
-      },
-      render: () => () => console.log('legacy render function called, it does nothing'),
-      events: this.props.eventBus || new EventBusSrv(),
-      range: getTimeSrv().timeRange(),
-    };
-  }
-
   /**
    * When datasource variables are used the query.datasource.uid property is a string variable expression
    * DataSourceSettings.uid can also be this variable expression.
@@ -181,7 +131,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
     this.setState({
       datasource: datasource as unknown as DataSourceApi<TQuery>,
       queriedDataSourceIdentifier: interpolatedUID,
-      hasTextEditMode: has(datasource, 'components.QueryCtrl.prototype.toggleEditorMode'),
     });
   }
 
@@ -197,56 +146,16 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
       const dataFilteredByRefId = filterPanelDataToQuery(data, query.refId);
 
       this.setState({ data: dataFilteredByRefId });
-
-      if (this.angularScope) {
-        this.angularScope.range = getTimeSrv().timeRange();
-      }
-
-      if (this.angularQueryEditor && dataFilteredByRefId) {
-        notifyAngularQueryEditorsOfData(this.angularScope!, dataFilteredByRefId, this.angularQueryEditor);
-      }
     }
 
     // check if we need to load another datasource
     if (datasource && queriedDataSourceIdentifier !== this.getInterpolatedDataSourceUID()) {
-      if (this.angularQueryEditor) {
-        this.angularQueryEditor.destroy();
-        this.angularQueryEditor = null;
-      }
       this.loadDatasource();
       return;
     }
-
-    if (!this.element || this.angularQueryEditor) {
-      return;
-    }
-
-    this.renderAngularQueryEditor();
   }
 
-  renderAngularQueryEditor = () => {
-    if (!this.element) {
-      return;
-    }
-
-    if (this.angularQueryEditor) {
-      this.angularQueryEditor.destroy();
-      this.angularQueryEditor = null;
-    }
-
-    const loader = getAngularLoader();
-    const template = '<plugin-component type="query-ctrl" />';
-    const scopeProps = { ctrl: this.getAngularQueryComponentScope() };
-
-    this.angularQueryEditor = loader.load(this.element, scopeProps, template);
-    this.angularScope = scopeProps.ctrl;
-  };
-
-  onOpen = () => {
-    this.renderAngularQueryEditor();
-  };
-
-  getReactQueryEditor(ds: DataSourceApi<TQuery>) {
+  getQueryEditor(ds: DataSourceApi<TQuery>) {
     if (!ds) {
       return;
     }
@@ -280,12 +189,8 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
       return null;
     }
 
-    if (datasource?.components?.QueryCtrl) {
-      return <div ref={(element) => (this.element = element)} />;
-    }
-
     if (datasource) {
-      let QueryEditor = this.getReactQueryEditor(datasource);
+      let QueryEditor = this.getQueryEditor(datasource);
 
       if (QueryEditor) {
         return (
@@ -317,17 +222,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
     );
   };
 
-  onToggleEditMode = (e: React.MouseEvent, props: QueryOperationRowRenderProps) => {
-    e.stopPropagation();
-    if (this.angularScope && this.angularScope.toggleEditorMode) {
-      this.angularScope.toggleEditorMode();
-      this.angularQueryEditor?.digest();
-      if (!props.isOpen) {
-        props.onOpen();
-      }
-    }
-  };
-
   onRemoveQuery = () => {
     const { onRemoveQuery, query, onQueryRemoved } = this.props;
     onRemoveQuery(query);
@@ -385,9 +279,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
       return datasource.getQueryDisplayText(this.props.query);
     }
 
-    if (this.angularScope && this.angularScope.getCollapsedText) {
-      return this.angularScope.getCollapsedText();
-    }
     return null;
   }
 
@@ -415,7 +306,8 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
     const colour = type === 'warning' ? 'orange' : 'blue';
     const iconName = type === 'warning' ? 'exclamation-triangle' : 'file-landscape-alt';
 
-    const serializedWarnings = uniqueWarnings.map((warning) => warning.text).join('\n');
+    const listItems = uniqueWarnings.map((warning) => warning.text);
+    const serializedWarnings = <List items={listItems} renderItem={(item) => <>{item}</>} />;
 
     return (
       <Badge
@@ -458,13 +350,19 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
 
     extraActions.push(this.renderWarnings('info'));
     extraActions.push(this.renderWarnings('warning'));
+    extraActions.push(<AdaptiveTelemetryQueryActions key="adaptive-telemetry-actions" query={query} />);
 
     return extraActions;
   };
 
   renderActions = (props: QueryOperationRowRenderProps) => {
-    const { query, hideHideQueryButton: hideHideQueryButton = false } = this.props;
-    const { hasTextEditMode, datasource, showingHelp } = this.state;
+    const {
+      query,
+      hideHideQueryButton: hideHideQueryButton = false,
+      onReplace,
+      onQueryReplacedFromLibrary,
+    } = this.props;
+    const { datasource, showingHelp } = this.state;
     const isHidden = !!query.hide;
 
     const hasEditorHelp = datasource?.components?.QueryEditorHelp;
@@ -479,15 +377,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
             active={showingHelp}
           />
         )}
-        {hasTextEditMode && (
-          <QueryOperationAction
-            title={t('query-operation.header.toggle-edit-mode', 'Toggle text edit mode')}
-            icon="pen"
-            onClick={(e) => {
-              this.onToggleEditMode(e, props);
-            }}
-          />
-        )}
         {this.renderExtraActions()}
         <MaybeQueryLibrarySaveButton query={query} />
         <QueryOperationAction
@@ -495,6 +384,13 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
           icon="copy"
           onClick={this.onCopyQuery}
         />
+        <ReplaceQueryFromLibrary
+          datasourceFilters={datasource?.name ? [datasource.name] : []}
+          onSelectQuery={(query) => {
+            onQueryReplacedFromLibrary?.();
+            onReplace?.(query);
+          }}
+        />
         {!hideHideQueryButton ? (
           <QueryOperationToggleAction
             dataTestId={selectors.components.QueryEditorRow.actionButton('Hide response')}
@@ -527,7 +423,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
         onChangeDataSource={onChangeDataSource}
         dataSource={dataSource}
         hidden={query.hide}
-        onClick={(e) => this.onToggleEditMode(e, props)}
         onChange={onChange}
         collapsedText={!props.isOpen ? this.renderCollapsedText() : null}
         renderExtras={renderHeaderExtras}
@@ -564,7 +459,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
           index={index}
           headerElement={this.renderHeader}
           actions={hideActionButtons ? undefined : this.renderActions}
-          onOpen={this.onOpen}
         >
           <div className={rowClasses} id={this.id}>
             <ErrorBoundaryAlert>
@@ -588,36 +482,6 @@ export class QueryEditorRow<TQuery extends DataQuery> extends PureComponent<Prop
   }
 }
 
-function notifyAngularQueryEditorsOfData<TQuery extends DataQuery>(
-  scope: AngularQueryComponentScope<TQuery>,
-  data: PanelData,
-  editor: AngularComponent
-) {
-  if (data.state === LoadingState.Done) {
-    const legacy = data.series.map((v) => toLegacyResponseData(v));
-    scope.events.emit(PanelEvents.dataReceived, legacy);
-  } else if (data.state === LoadingState.Error) {
-    scope.events.emit(PanelEvents.dataError, data.error);
-  }
-
-  // Some query controllers listen to data error events and need a digest
-  // for some reason this needs to be done in next tick
-  setTimeout(editor.digest);
-}
-
-export interface AngularQueryComponentScope<TQuery extends DataQuery> {
-  target: TQuery;
-  panel: PanelModel;
-  dashboard: DashboardModel;
-  events: EventBusExtended;
-  refresh: () => void;
-  render: () => void;
-  datasource: DataSourceApi<TQuery> | null;
-  toggleEditorMode?: () => void;
-  getCollapsedText?: () => string;
-  range: TimeRange;
-}
-
 /**
  * Get a version of the PanelData limited to the query we are looking at
  */
@@ -664,3 +528,51 @@ function MaybeQueryLibrarySaveButton(props: { query: DataQuery }) {
   const { renderSaveQueryButton } = useQueryLibraryContext();
   return renderSaveQueryButton(props.query);
 }
+
+interface ReplaceQueryFromLibraryProps<TQuery extends DataQuery> {
+  datasourceFilters: string[];
+  onSelectQuery: (query: DataQuery) => void;
+}
+
+function ReplaceQueryFromLibrary<TQuery extends DataQuery>({
+  datasourceFilters,
+  onSelectQuery,
+}: ReplaceQueryFromLibraryProps<TQuery>) {
+  const { openDrawer, queryLibraryEnabled } = useQueryLibraryContext();
+
+  const onReplaceQueryFromLibrary = () => {
+    openDrawer(datasourceFilters, onSelectQuery, { isReplacingQuery: true });
+  };
+
+  return queryLibraryEnabled ? (
+    <QueryOperationAction
+      title={t('query-operation.header.replace-query-from-library', 'Replace with query from library')}
+      icon="book"
+      onClick={onReplaceQueryFromLibrary}
+    />
+  ) : null;
+}
+
+function AdaptiveTelemetryQueryActions({ query }: { query: DataQuery }) {
+  try {
+    const { isLoading, components } = usePluginComponents<PluginExtensionQueryEditorRowAdaptiveTelemetryV1Context>({
+      extensionPointId: PluginExtensionPoints.QueryEditorRowAdaptiveTelemetryV1,
+    });
+
+    if (isLoading || !components.length) {
+      return null;
+    }
+
+    return renderLimitedComponents({
+      props: { query, contextHints: ['queryeditorrow', 'header'] },
+      components,
+      limit: 1,
+      pluginId: /grafana-adaptive.*/,
+    });
+  } catch (error) {
+    // If `usePluginComponents` isn't properly resolved, tests will fail with 'setPluginComponentsHook(options) can only be used after the Grafana instance has started.'
+    // This will be resolved in https://github.com/grafana/grafana/pull/92983
+    // In this case, Return `null` like when there are no extensions.
+    return null;
+  }
+}
