@@ -5,7 +5,8 @@ import {
   TransformerUIProps,
   TransformerCategory,
 } from '@grafana/data';
-import { MergeTransformerOptions } from '@grafana/data/src/transformations/transformers/merge';
+import { MergeTransformerOptions } from '@grafana/data/internal';
+import { Trans } from '@grafana/i18n';
 import { FieldValidationMessage } from '@grafana/ui';
 
 import { getTransformationContent } from '../docs/getTransformationContent';
@@ -13,7 +14,13 @@ import { getTransformationContent } from '../docs/getTransformationContent';
 export const MergeTransformerEditor = ({ input, options, onChange }: TransformerUIProps<MergeTransformerOptions>) => {
   if (input.length <= 1) {
     // Show warning that merge is useless only apply on a single frame
-    return <FieldValidationMessage>Merge has no effect when applied on a single frame.</FieldValidationMessage>;
+    return (
+      <FieldValidationMessage>
+        <Trans i18nKey="transformers.merge-transformer-editor.merge-effect-applied-single-frame">
+          Merge has no effect when applied on a single frame.
+        </Trans>
+      </FieldValidationMessage>
+    );
   }
   return null;
 };
