@@ -1,5 +1,8 @@
 //DOCS: https://prometheus.io/docs/alerting/latest/configuration/
 import { DataSourceJsonData, WithAccessControlMetadata } from '@grafana/data';
+import { IoK8SApimachineryPkgApisMetaV1ObjectMeta } from 'app/features/alerting/unified/openapi/receiversApi.gen';
+
+export const ROUTES_META_SYMBOL = Symbol('routes_metadata');
 
 export type AlertManagerCortexConfig = {
   template_files: Record<string, string>;
@@ -65,14 +68,30 @@ export type WebhookConfig = {
   max_alerts?: number;
 };
 
+type GrafanaManagedReceiverConfigSettings<T = any> = Record<string, T>;
+export type GrafanaManagedReceiverSecureFields = Record<string, boolean>;
+
 export type GrafanaManagedReceiverConfig = {
   uid?: string;
-  disableResolveMessage: boolean;
-  secureFields?: Record<string, boolean>;
-  secureSettings?: Record<string, any>;
-  settings?: Record<string, any>; // sometimes settings are optional for security reasons (RBAC)
+  disableResolveMessage?: boolean;
+  /**
+   * Secure fields keys values should be true if they are already configured in the database
+   * To reset the secure field, omit the key from the object when updating the receiver
+   */
+  secureFields?: GrafanaManagedReceiverSecureFields;
+  /** If retrieved from k8s API, SecureSettings property name is different */
+  // SecureSettings?: GrafanaManagedReceiverConfigSettings<boolean>;
+  settings: GrafanaManagedReceiverConfigSettings;
   type: string;
-  name: string;
+  /**
+   * Name of the _receiver_, which in most cases will be the
+   * same as the contact point's name. This should not be used, and is optional because the
+   * kubernetes API does not return it for us (and we don't want to/shouldn't use it)
+   *
+   * @deprecated Do not rely on this property - it won't be present in kuberenetes API responses
+   * and should be the same as the contact point name anyway
+   */
+  name?: string;
   updated?: string;
   created?: string;
   provenance?: string;
@@ -80,6 +99,10 @@ export type GrafanaManagedReceiverConfig = {
 
 export interface GrafanaManagedContactPoint {
   name: string;
+  /** If parsed from k8s API, we'll have an ID property */
+  id?: string;
+  metadata?: IoK8SApimachineryPkgApisMetaV1ObjectMeta;
+  provisioned?: boolean;
   grafana_managed_receiver_configs?: GrafanaManagedReceiverConfig[];
 }
 
@@ -111,9 +134,18 @@ export type Route = {
   group_interval?: string;
   repeat_interval?: string;
   routes?: Route[];
+  /** Times when the route should be muted. */
   mute_time_intervals?: string[];
+  /** Times when the route should be active. This is the opposite of `mute_time_intervals` */
+  active_time_intervals?: string[];
   /** only the root policy might have a provenance field defined */
   provenance?: string;
+  /** this is used to add additional metadata to the routes without interfering with original route definition (symbols aren't iterable)  */
+  [ROUTES_META_SYMBOL]?: {
+    provisioned?: boolean;
+    resourceVersion?: string;
+    name?: string;
+  };
 };
 
 export interface RouteWithID extends Route {
@@ -330,7 +362,7 @@ export interface TimeInterval {
 export type MuteTimeInterval = {
   name: string;
   time_intervals: TimeInterval[];
-  provenance?: string;
+  provisioned?: boolean;
 };
 
 export interface AlertManagerDataSourceJsonData extends DataSourceJsonData {
