@@ -1,20 +1,18 @@
-import { css } from '@emotion/css';
 import { useMemo, useState } from 'react';
-import { useMeasure } from 'react-use';
 
-import { DashboardCursorSync, DataFrame, PanelProps } from '@grafana/data';
+import { DashboardCursorSync, PanelProps } from '@grafana/data';
+import { PanelDataErrorView } from '@grafana/runtime';
 import {
+  AxisPlacement,
   EventBusPlugin,
-  Pagination,
   TooltipDisplayMode,
   TooltipPlugin2,
   usePanelContext,
   useTheme2,
 } from '@grafana/ui';
-import { TimeRange2, TooltipHoverMode } from '@grafana/ui/src/components/uPlot/plugins/TooltipPlugin2';
+import { TimeRange2, TooltipHoverMode } from '@grafana/ui/internal';
 import { TimelineChart } from 'app/core/components/TimelineChart/TimelineChart';
 import {
-  makeFramePerSeries,
   prepareTimelineFields,
   prepareTimelineLegendItems,
   TimelineMode,
@@ -25,73 +23,11 @@ import { OutsideRangePlugin } from '../timeseries/plugins/OutsideRangePlugin';
 import { getTimezones } from '../timeseries/utils';
 
 import { StateTimelineTooltip2 } from './StateTimelineTooltip2';
-import { Options, defaultOptions } from './panelcfg.gen';
+import { Options } from './panelcfg.gen';
+import { containerStyles, usePagination } from './utils';
 
 interface TimelinePanelProps extends PanelProps<Options> {}
 
-const styles = {
-  container: css({
-    display: 'flex',
-    flexDirection: 'column',
-  }),
-  paginationContainer: css({
-    display: 'flex',
-    justifyContent: 'center',
-    width: '100%',
-  }),
-  paginationElement: css({
-    marginTop: '8px',
-  }),
-};
-
-function usePagination(frames?: DataFrame[], perPage?: number) {
-  const [currentPage, setCurrentPage] = useState(1);
-
-  const [paginationWrapperRef, { height: paginationHeight, width: paginationWidth }] = useMeasure<HTMLDivElement>();
-
-  const pagedFrames = useMemo(
-    () => (!perPage || frames == null ? frames : makeFramePerSeries(frames)),
-    [frames, perPage]
-  );
-
-  if (!perPage || pagedFrames == null) {
-    return {
-      paginatedFrames: pagedFrames,
-      paginationRev: 'disabled',
-      paginationElement: undefined,
-      paginationHeight: 0,
-    };
-  }
-
-  perPage ||= defaultOptions.perPage!;
-
-  const numberOfPages = Math.ceil(pagedFrames.length / perPage);
-  // `perPage` changing might lead to temporarily too large values of `currentPage`.
-  const currentPageCapped = Math.min(currentPage, numberOfPages);
-  const pageOffset = (currentPageCapped - 1) * perPage;
-  const currentPageFrames = pagedFrames.slice(pageOffset, pageOffset + perPage);
-
-  // `paginationRev` needs to change value whenever any of the pagination settings changes.
-  // It's used in to trigger a reconfiguration of the underlying graphs (which is cached,
-  // hence an explicit nudge is required).
-  const paginationRev = `${currentPageCapped}/${perPage}`;
-
-  const showSmallVersion = paginationWidth < 550;
-  const paginationElement = (
-    <div className={styles.paginationContainer} ref={paginationWrapperRef}>
-      <Pagination
-        className={styles.paginationElement}
-        currentPage={currentPageCapped}
-        numberOfPages={numberOfPages}
-        showSmallVersion={showSmallVersion}
-        onNavigate={setCurrentPage}
-      />
-    </div>
-  );
-
-  return { paginatedFrames: currentPageFrames, paginationRev, paginationElement, paginationHeight };
-}
-
 /**
  * @alpha
  */
@@ -102,8 +38,10 @@ export const StateTimelinePanel = ({
   options,
   width,
   height,
+  fieldConfig,
   replaceVariables,
   onChangeTimeRange,
+  id: panelId,
 }: TimelinePanelProps) => {
   const theme = useTheme2();
 
@@ -129,18 +67,14 @@ export const StateTimelinePanel = ({
 
   const timezones = useMemo(() => getTimezones(options.timezone, timeZone), [options.timezone, timeZone]);
 
-  if (!paginatedFrames || warn) {
-    return (
-      <div className="panel-empty">
-        <p>{warn ?? 'No data found in response'}</p>
-      </div>
-    );
+  if (!paginatedFrames || typeof warn === 'string') {
+    return <PanelDataErrorView panelId={panelId} fieldConfig={fieldConfig} data={data} message={warn} needsTimeField />;
   }
 
   const enableAnnotationCreation = Boolean(canAddAnnotations && canAddAnnotations());
 
   return (
-    <div className={styles.container}>
+    <div className={containerStyles.container}>
       <TimelineChart
         theme={theme}
         frames={paginatedFrames}
@@ -172,7 +106,10 @@ export const StateTimelinePanel = ({
                   queryZoom={onChangeTimeRange}
                   syncMode={cursorSync}
                   syncScope={eventsScope}
-                  render={(u, dataIdxs, seriesIdx, isPinned, dismiss, timeRange2, viaSync) => {
+                  getDataLinks={(seriesIdx, dataIdx) =>
+                    alignedFrame.fields[seriesIdx].getLinks?.({ valueRowIndex: dataIdx }) ?? []
+                  }
+                  render={(u, dataIdxs, seriesIdx, isPinned, dismiss, timeRange2, viaSync, dataLinks) => {
                     if (enableAnnotationCreation && timeRange2 != null) {
                       setNewAnnotationRange(timeRange2);
                       dismiss();
@@ -199,21 +136,23 @@ export const StateTimelinePanel = ({
                         withDuration={true}
                         maxHeight={options.tooltip.maxHeight}
                         replaceVariables={replaceVariables}
+                        dataLinks={dataLinks}
                       />
                     );
                   }}
                   maxWidth={options.tooltip.maxWidth}
                 />
               )}
-              {/* Renders annotations */}
-              <AnnotationsPlugin2
-                annotations={data.annotations ?? []}
-                config={builder}
-                timeZone={timeZone}
-                newRange={newAnnotationRange}
-                setNewRange={setNewAnnotationRange}
-                canvasRegionRendering={false}
-              />
+              {alignedFrame.fields[0].config.custom?.axisPlacement !== AxisPlacement.Hidden && (
+                <AnnotationsPlugin2
+                  annotations={data.annotations ?? []}
+                  config={builder}
+                  timeZone={timeZone}
+                  newRange={newAnnotationRange}
+                  setNewRange={setNewAnnotationRange}
+                  canvasRegionRendering={false}
+                />
+              )}
               <OutsideRangePlugin config={builder} onChangeTimeRange={onChangeTimeRange} />
             </>
           );
