@@ -9,6 +9,14 @@ describe('isSoloRoute', () => {
         )
       ).toBe(true);
     });
+
+    it('then it should return true for a dashboard-solo route', () => {
+      expect(
+        isSoloRoute(
+          'http://localhost:3000/render/dashboard-solo/4vEk45n7k/dash?orgId=1&from=1629329071059&to=1629350671060&panelId=5&width=1000&height=500&tz=Europe%2FStockholm'
+        )
+      ).toBe(true);
+    });
   });
 
   describe('when called without a solo route', () => {
